[mpich2-dev] [PATCH 2/2] Issue 4920: Rename and Move MPI_Pint and Related MPI_Aint Casting Macros

Jeff Parker jjparker at us.ibm.com
Fri May 16 07:24:50 CDT 2008


This patch is intended to be applied together with PATCH 1/2 and on top of the
already-submitted "MPI_Aint on 32-bit platform" patches.

Refer to PATCH 1/2 for further details.

Signed-off-by: Jeff Parker <jjparker at us.ibm.com>
---
 mpich2/src/binding/f77/buildiface                  |   12 ++--
 mpich2/src/mpe2/src/logging/src/clog_commset.c     |    4 +-
 mpich2/src/mpi/attr/attrutil.c                     |   12 ++--
 mpich2/src/mpi/attr/win_get_attr.c                 |    2 +-
 mpich2/src/mpi/coll/allgather.c                    |    2 +-
 mpich2/src/mpi/coll/alltoall.c                     |    4 +-
 mpich2/src/mpi/coll/alltoallv.c                    |    8 +-
 mpich2/src/mpi/coll/gather.c                       |    8 +-
 mpich2/src/mpi/coll/gatherv.c                      |    8 +-
 mpich2/src/mpi/coll/scatter.c                      |    4 +-
 mpich2/src/mpi/coll/scatterv.c                     |    2 +-
 mpich2/src/mpi/datatype/address.c                  |    4 +-
 mpich2/src/mpi/datatype/get_address.c              |    4 +-
 mpich2/src/mpi/datatype/pack.c                     |    2 +-
 mpich2/src/mpi/datatype/pack_external.c            |    4 +-
 mpich2/src/mpi/datatype/type_create_hvector.c      |    2 +-
 mpich2/src/mpi/datatype/type_create_resized.c      |    4 +-
 mpich2/src/mpi/datatype/type_hvector.c             |    2 +-
 mpich2/src/mpi/datatype/unpack.c                   |    2 +-
 mpich2/src/mpi/datatype/unpack_external.c          |    4 +-
 mpich2/src/mpi/rma/accumulate.c                    |    2 +-
 mpich2/src/mpi/rma/alloc_mem.c                     |    2 +-
 mpich2/src/mpi/rma/get.c                           |    2 +-
 mpich2/src/mpi/rma/put.c                           |    2 +-
 mpich2/src/mpi/rma/win_create.c                    |    2 +-
 mpich2/src/mpi/romio/adio/ad_bgl/ad_bgl_aggrs.c    |   32 +++++-----
 mpich2/src/mpi/romio/adio/ad_bgl/ad_bgl_rdcoll.c   |    6 +-
 mpich2/src/mpi/romio/adio/ad_bgl/ad_bgl_wrcoll.c   |    4 +-
 mpich2/src/mpi/romio/adio/common/ad_read_coll.c    |    6 +-
 .../src/mpi/romio/adio/common/ad_read_str_naive.c  |    6 +-
 mpich2/src/mpi/romio/adio/common/ad_write_coll.c   |    4 +-
 mpich2/src/mpi/romio/adio/common/ad_write_nolock.c |    2 +-
 .../src/mpi/romio/adio/common/ad_write_str_naive.c |    6 +-
 mpich2/src/mpi/romio/adio/include/adioi.h          |    6 +-
 .../src/mpid/common/datatype/dataloop/dataloop.c   |   60 ++++++++--------
 .../datatype/dataloop/dataloop_create_pairtype.c   |    2 +-
 .../datatype/dataloop/dataloop_create_struct.c     |    2 +-
 .../mpid/common/datatype/dataloop/segment_ops.c    |   70 ++++++++++----------
 mpich2/src/mpid/common/datatype/dataloop/veccpy.h  |   12 ++--
 mpich2/src/mpid/common/datatype/mpid_segment.c     |   16 ++--
 .../common/datatype/mpid_type_create_pairtype.c    |    2 +-
 .../dcmfd/src/coll/allgather/mpido_allgather.c     |    8 +-
 .../dcmfd/src/coll/allgatherv/mpido_allgatherv.c   |    8 +-
 .../dcmfd/src/coll/allreduce/mpido_allreduce.c     |    4 +-
 .../mpid/dcmfd/src/coll/alltoall/mpido_alltoall.c  |    4 +-
 .../dcmfd/src/coll/alltoallv/mpido_alltoallv.c     |    4 +-
 .../dcmfd/src/coll/alltoallw/mpido_alltoallw.c     |    4 +-
 mpich2/src/mpid/dcmfd/src/coll/bcast/mpido_bcast.c |    2 +-
 .../src/mpid/dcmfd/src/coll/gather/mpido_gather.c  |    4 +-
 .../src/mpid/dcmfd/src/coll/reduce/mpido_reduce.c  |    4 +-
 .../src/coll/reduce_scatter/mpido_reduce_scatter.c |    2 +-
 .../mpid/dcmfd/src/coll/scatter/mpido_scatter.c    |    4 +-
 .../mpid/dcmfd/src/coll/scatterv/mpido_scatterv.c  |    4 +-
 53 files changed, 196 insertions(+), 196 deletions(-)

diff --git a/mpich2/src/binding/f77/buildiface b/mpich2/src/binding/f77/buildiface
index b140983..2a6e705 100755
--- a/mpich2/src/binding/f77/buildiface
+++ b/mpich2/src/binding/f77/buildiface
@@ -1388,7 +1388,7 @@ sub addrint_in_decl {
 }
 sub addrint_in_arg {
     my $count = $_[0];
-    print $OUTFD "MPI_AINT_CAST_TO_VOID_PTR(MPI_Aint)((int)*(int *)v$count)";
+    print $OUTFD "MPIR_MPI_AINT_CAST_TO_VOID_PTR(MPI_Aint)((int)*(int *)v$count)";
 }
 
 sub attrint_ctof {
@@ -1402,7 +1402,7 @@ sub attrint_ctof {
         *(MPI_Fint*)$cvar = 0;
     }
     else {
-        *(MPI_Fint*)$cvar = (MPI_Fint)MPI_VOID_PTR_CAST_TO_MPI_AINT attr$cvar;
+        *(MPI_Fint*)$cvar = (MPI_Fint)MPIR_VOID_PTR_CAST_TO_MPI_AINT attr$cvar;
     }\n";
 }
 
@@ -1428,7 +1428,7 @@ sub addraint_in_decl {
 }
 sub addraint_in_arg {
     my $count = $_[0];
-    print $OUTFD "MPI_AINT_CAST_TO_VOID_PTR(MPI_Aint)((MPI_Aint)*(MPI_Aint *)v$count)";
+    print $OUTFD "MPIR_MPI_AINT_CAST_TO_VOID_PTR(MPI_Aint)((MPI_Aint)*(MPI_Aint *)v$count)";
 }
 
 sub attraint_ctof {
@@ -1440,7 +1440,7 @@ sub attraint_ctof {
         *(MPI_Aint*)$cvar = 0;
     }
     else {
-        *(MPI_Aint*)$cvar = MPI_VOID_PTR_CAST_TO_MPI_AINT attr$cvar;
+        *(MPI_Aint*)$cvar = MPIR_VOID_PTR_CAST_TO_MPI_AINT attr$cvar;
     }\n";
 }
 
@@ -2632,7 +2632,7 @@ FORT_DLL_SPEC void FORT_CALL mpirinitc2_( char *a FORT_MIXED_LEN(d1)
 #ifdef USE_POINTER_FOR_BOTTOM
     b = a;
 #else
-    b = a - MPI_VOID_PTR_CAST_TO_MPI_AINT MPIR_F_MPI_BOTTOM;
+    b = a - MPIR_VOID_PTR_CAST_TO_MPI_AINT MPIR_F_MPI_BOTTOM;
 #endif
     *v2 = (MPI_Fint)( b );
 #ifdef HAVE_AINT_LARGER_THAN_FINT
@@ -2671,7 +2671,7 @@ FORT_DLL_SPEC void FORT_CALL mpirinitc2_( char *a FORT_MIXED_LEN(d1)
     &specialInitStatement( $OUTFD );
     print $OUTFD "\
 #ifndef USE_POINTER_FOR_BOTTOM
-    a = a - MPI_VOID_PTR_CAST_TO_MPI_AINT MPIR_F_MPI_BOTTOM;
+    a = a - MPIR_VOID_PTR_CAST_TO_MPI_AINT MPIR_F_MPI_BOTTOM;
 #endif
     *v2 =  a;
 }\n";
diff --git a/mpich2/src/mpe2/src/logging/src/clog_commset.c b/mpich2/src/mpe2/src/logging/src/clog_commset.c
index 09711f7..3414a29 100644
--- a/mpich2/src/mpe2/src/logging/src/clog_commset.c
+++ b/mpich2/src/mpe2/src/logging/src/clog_commset.c
@@ -303,7 +303,7 @@ const CLOG_CommIDs_t *CLOG_CommSet_add_intracomm( CLOG_CommSet_t *commset,
 
     /* Set the input MPI_Comm's LID_key attribute with new local CommID's LID */
     PMPI_Comm_set_attr( intracomm, commset->LID_key,
-               MPI_AINT_CAST_TO_VOID_PTR (MPI_Aint) intracommIDs->local_ID );
+               MPIR_MPI_AINT_CAST_TO_VOID_PTR (MPI_Aint) intracommIDs->local_ID );
 
     /* Set the Comm field */
     intracommIDs->comm   = intracomm;
@@ -358,7 +358,7 @@ CLOG_CommSet_add_intercomm(       CLOG_CommSet_t *commset,
 
     /* Set the input MPI_Comm's LID_key attribute with new local CommID */
     PMPI_Comm_set_attr( intercomm, commset->LID_key,
-             MPI_AINT_CAST_TO_VOID_PTR (MPI_Aint) intercommIDs->local_ID );
+             MPIR_MPI_AINT_CAST_TO_VOID_PTR (MPI_Aint) intercommIDs->local_ID );
 
     /* Set the Comm field with the intercomm's info */
     intercommIDs->comm   = intercomm;
diff --git a/mpich2/src/mpi/attr/attrutil.c b/mpich2/src/mpi/attr/attrutil.c
index 99497b5..c3b314c 100644
--- a/mpich2/src/mpi/attr/attrutil.c
+++ b/mpich2/src/mpi/attr/attrutil.c
@@ -119,7 +119,7 @@ int MPIR_Call_attr_delete( int handle, MPID_Attribute *attr_p )
                    are MPI_Fint values, and we assume 
 		   sizeof(MPI_Fint) <= sizeof(MPI_Aint).  
 		   See also src/binding/f77/attr_getf.c . */
-		fvalue  = (MPI_Fint) MPI_VOID_PTR_CAST_TO_MPI_AINT (attr_p->value);
+		fvalue  = (MPI_Fint) MPIR_VOID_PTR_CAST_TO_MPI_AINT (attr_p->value);
 		fextra  = (MPI_Fint*) (attr_p->keyval->extra_state);
 		delfn.F77_DeleteFunction( &fhandle, &fkeyval, &fvalue, 
 					  fextra, &ierr );
@@ -141,7 +141,7 @@ int MPIR_Call_attr_delete( int handle, MPID_Attribute *attr_p )
 	    if (delfn.F90_DeleteFunction) {
 		fhandle = (MPI_Fint) (handle);
 		fkeyval = (MPI_Fint) (attr_p->keyval->handle);
-		fvalue  = MPI_VOID_PTR_CAST_TO_MPI_AINT (attr_p->value);
+		fvalue  = MPIR_VOID_PTR_CAST_TO_MPI_AINT (attr_p->value);
 		fextra  = (MPI_Aint*) (attr_p->keyval->extra_state );
 		delfn.F90_DeleteFunction( &fhandle, &fkeyval, &fvalue, 
 					  fextra, &ierr );
@@ -241,13 +241,13 @@ int MPIR_Attr_dup_list( int handle, MPID_Attribute *old_attrs,
 		    fkeyval = (MPI_Fint) (p->keyval->handle);
 		    /* The following cast can lose data on systems whose
 		       pointers are longer than integers */
-		    fvalue  = (MPI_Fint) MPI_VOID_PTR_CAST_TO_MPI_AINT (p->value);
+		    fvalue  = (MPI_Fint) MPIR_VOID_PTR_CAST_TO_MPI_AINT (p->value);
 		    fextra  = (MPI_Fint*) (p->keyval->extra_state );
 		    copyfn.F77_CopyFunction( &fhandle, &fkeyval, fextra,
 					     &fvalue, &fnew, &fflag, &ierr );
 		    if (ierr) mpi_errno = (int)ierr;
 		    flag      = fflag;
-		    new_value = MPI_AINT_CAST_TO_VOID_PTR (MPI_Aint) fnew;
+		    new_value = MPIR_MPI_AINT_CAST_TO_VOID_PTR (MPI_Aint) fnew;
 		    /* --BEGIN ERROR HANDLING-- */
 		    if (mpi_errno != 0)
 		    {
@@ -264,13 +264,13 @@ int MPIR_Attr_dup_list( int handle, MPID_Attribute *old_attrs,
 		    MPI_Aint fvalue, fnew, *fextra;
 		    fhandle = (MPI_Fint) (handle);
 		    fkeyval = (MPI_Fint) (p->keyval->handle);
-		    fvalue  = MPI_VOID_PTR_CAST_TO_MPI_AINT (p->value);
+		    fvalue  = MPIR_VOID_PTR_CAST_TO_MPI_AINT (p->value);
 		    fextra  = (MPI_Aint*) (p->keyval->extra_state );
 		    copyfn.F90_CopyFunction( &fhandle, &fkeyval, fextra,
 					     &fvalue, &fnew, &fflag, &ierr );
 		    if (ierr) mpi_errno = (int)ierr;
 		    flag = fflag;
-		    new_value = MPI_AINT_CAST_TO_VOID_PTR fnew;
+		    new_value = MPIR_MPI_AINT_CAST_TO_VOID_PTR fnew;
 		    /* --BEGIN ERROR HANDLING-- */
 		    if (mpi_errno != 0)
 		    {
diff --git a/mpich2/src/mpi/attr/win_get_attr.c b/mpich2/src/mpi/attr/win_get_attr.c
index b862716..7e577fd 100644
--- a/mpich2/src/mpi/attr/win_get_attr.c
+++ b/mpich2/src/mpi/attr/win_get_attr.c
@@ -156,7 +156,7 @@ int MPI_Win_get_attr(MPI_Win win, int win_keyval, void *attribute_val,
 	case 2: /* Fortran BASE */
 	    /* The Fortran routine that matches this routine should
 	       provide an address-sized integer, not an MPI_Fint */
-	    *attr_int = MPI_VOID_PTR_CAST_TO_MPI_AINT (win_ptr->base);
+	    *attr_int = MPIR_VOID_PTR_CAST_TO_MPI_AINT (win_ptr->base);
 	    break;
 	case 4: /* Fortran SIZE */
 	    /* We do not need to copy because we return the value,
diff --git a/mpich2/src/mpi/coll/allgather.c b/mpich2/src/mpi/coll/allgather.c
index b4b8f52..57d7dcd 100644
--- a/mpich2/src/mpi/coll/allgather.c
+++ b/mpich2/src/mpi/coll/allgather.c
@@ -107,7 +107,7 @@ int MPIR_Allgather (
     MPID_Datatype_get_size_macro( recvtype, type_size );
 
     /* This is the largest offset we add to recvbuf */
-    MPID_Ensure_Aint_fits_in_pointer(MPI_VOID_PTR_CAST_TO_MPI_AINT recvbuf + 
+    MPID_Ensure_Aint_fits_in_pointer(MPIR_VOID_PTR_CAST_TO_MPI_AINT recvbuf + 
       (comm_size * recvcount * recvtype_extent));
 
     /* check if comm_size is a power of two */
diff --git a/mpich2/src/mpi/coll/alltoall.c b/mpich2/src/mpi/coll/alltoall.c
index 4e47efb..8ac96ad 100644
--- a/mpich2/src/mpi/coll/alltoall.c
+++ b/mpich2/src/mpi/coll/alltoall.c
@@ -537,10 +537,10 @@ int MPIR_Alltoall_inter(
     /* Do the pairwise exchanges */
     max_size = MPIR_MAX(local_size, remote_size);
     MPID_Ensure_Aint_fits_in_pointer(
-      (MPI_VOID_PTR_CAST_TO_MPI_AINT recvbuf + 
+      (MPIR_VOID_PTR_CAST_TO_MPI_AINT recvbuf + 
          max_size*recvcount*recvtype_extent));
     MPID_Ensure_Aint_fits_in_pointer(
-      (MPI_VOID_PTR_CAST_TO_MPI_AINT sendbuf + 
+      (MPIR_VOID_PTR_CAST_TO_MPI_AINT sendbuf + 
          max_size*sendcount*sendtype_extent));
     for (i=0; i<max_size; i++) {
         src = (rank - i + max_size) % max_size;
diff --git a/mpich2/src/mpi/coll/alltoallv.c b/mpich2/src/mpi/coll/alltoallv.c
index 4ec5040..792290d 100644
--- a/mpich2/src/mpi/coll/alltoallv.c
+++ b/mpich2/src/mpi/coll/alltoallv.c
@@ -99,7 +99,7 @@ int MPIR_Alltoallv (
         dst = (rank+i) % comm_size;
         if (recvcnts[dst]) {
     MPID_Ensure_Aint_fits_in_pointer((
-      MPI_VOID_PTR_CAST_TO_MPI_AINT recvbuf + rdispls[dst]*recv_extent));
+      MPIR_VOID_PTR_CAST_TO_MPI_AINT recvbuf + rdispls[dst]*recv_extent));
             mpi_errno = MPIC_Irecv((char *)recvbuf+rdispls[dst]*recv_extent, 
                                    recvcnts[dst], recvtype, dst,
                                    MPIR_ALLTOALLV_TAG, comm,
@@ -119,7 +119,7 @@ int MPIR_Alltoallv (
         dst = (rank+i) % comm_size;
         if (sendcnts[dst]) {
     MPID_Ensure_Aint_fits_in_pointer((
-      MPI_VOID_PTR_CAST_TO_MPI_AINT sendbuf + sdispls[dst]*send_extent));
+      MPIR_VOID_PTR_CAST_TO_MPI_AINT sendbuf + sdispls[dst]*send_extent));
             mpi_errno = MPIC_Isend((char *)sendbuf+sdispls[dst]*send_extent, 
                                    sendcnts[dst], sendtype, dst,
                                    MPIR_ALLTOALLV_TAG, comm,
@@ -214,7 +214,7 @@ int MPIR_Alltoallv_inter (
         }
         else {
             MPID_Ensure_Aint_fits_in_pointer ((
-             MPI_VOID_PTR_CAST_TO_MPI_AINT recvbuf + rdispls[src]*recv_extent));
+             MPIR_VOID_PTR_CAST_TO_MPI_AINT recvbuf + rdispls[src]*recv_extent));
             recvaddr = (char *)recvbuf + rdispls[src]*recv_extent;
             recvcount = recvcnts[src];
         }
@@ -225,7 +225,7 @@ int MPIR_Alltoallv_inter (
         }
         else {
             MPID_Ensure_Aint_fits_in_pointer ((
-             MPI_VOID_PTR_CAST_TO_MPI_AINT sendbuf + sdispls[dst]*send_extent));
+             MPIR_VOID_PTR_CAST_TO_MPI_AINT sendbuf + sdispls[dst]*send_extent));
             sendaddr = (char *)sendbuf + sdispls[dst]*send_extent;
             sendcount = sendcnts[dst];
         }
diff --git a/mpich2/src/mpi/coll/gather.c b/mpich2/src/mpi/coll/gather.c
index f0e89de..e78d2a4 100644
--- a/mpich2/src/mpi/coll/gather.c
+++ b/mpich2/src/mpi/coll/gather.c
@@ -98,7 +98,7 @@ int MPIR_Gather (
     if (rank == root) 
     {
         MPID_Datatype_get_extent_macro(recvtype, extent);
-        MPID_Ensure_Aint_fits_in_pointer(MPI_VOID_PTR_CAST_TO_MPI_AINT recvbuf+
+        MPID_Ensure_Aint_fits_in_pointer(MPIR_VOID_PTR_CAST_TO_MPI_AINT recvbuf+
                                           (extent*recvcnt*comm_size));
     }
 
@@ -256,10 +256,10 @@ int MPIR_Gather (
 		}
 		else {
 		    blocks[0] = sendcnt;
-		    struct_displs[0] = MPI_VOID_PTR_CAST_TO_MPI_AINT sendbuf;
+		    struct_displs[0] = MPIR_VOID_PTR_CAST_TO_MPI_AINT sendbuf;
 		    types[0] = sendtype;
 		    blocks[1] = curr_cnt - nbytes;
-		    struct_displs[1] = MPI_VOID_PTR_CAST_TO_MPI_AINT tmp_buf;
+		    struct_displs[1] = MPIR_VOID_PTR_CAST_TO_MPI_AINT tmp_buf;
 		    types[1] = MPI_BYTE;
 
 		    NMPI_Type_create_struct(2, blocks, struct_displs, types, &tmp_type);
@@ -547,7 +547,7 @@ int MPIR_Gather_inter (
 	{
             MPID_Datatype_get_extent_macro(recvtype, extent);
             MPID_Ensure_Aint_fits_in_pointer(
-               MPI_VOID_PTR_CAST_TO_MPI_AINT recvbuf + 
+               MPIR_VOID_PTR_CAST_TO_MPI_AINT recvbuf + 
                (recvcnt*remote_size*extent));
 
             for (i=0; i<remote_size; i++)
diff --git a/mpich2/src/mpi/coll/gatherv.c b/mpich2/src/mpi/coll/gatherv.c
index 8a3c3f9..2ee36b3 100644
--- a/mpich2/src/mpi/coll/gatherv.c
+++ b/mpich2/src/mpi/coll/gatherv.c
@@ -73,7 +73,7 @@ int MPIR_Gatherv (
 
          /* each node can make sure it is not going to overflow aint */
         MPID_Ensure_Aint_fits_in_pointer((
-         MPI_VOID_PTR_CAST_TO_MPI_AINT recvbuf + displs[rank] * extent));
+         MPIR_VOID_PTR_CAST_TO_MPI_AINT recvbuf + displs[rank] * extent));
 
         for ( i=0; i<root; i++ ) {
             if (recvcnts[i]) {
@@ -93,7 +93,7 @@ int MPIR_Gatherv (
         if (sendbuf != MPI_IN_PLACE) {
             if (recvcnts[rank]) {
                MPID_Ensure_Aint_fits_in_pointer((
-                  MPI_VOID_PTR_CAST_TO_MPI_AINT recvbuf + displs[rank]*extent));
+                  MPIR_VOID_PTR_CAST_TO_MPI_AINT recvbuf + displs[rank]*extent));
                 mpi_errno = MPIR_Localcopy(sendbuf, sendcnt, sendtype,
                                            ((char *)recvbuf+displs[rank]*extent), 
                                            recvcnts[rank], recvtype);
@@ -107,7 +107,7 @@ int MPIR_Gatherv (
             }
         }
         MPID_Ensure_Aint_fits_in_pointer((
-         MPI_VOID_PTR_CAST_TO_MPI_AINT recvbuf + displs[rank] * extent));
+         MPIR_VOID_PTR_CAST_TO_MPI_AINT recvbuf + displs[rank] * extent));
 
         for ( i=root+1; i<comm_size; i++ ) {
             if (recvcnts[i]) {
@@ -132,7 +132,7 @@ int MPIR_Gatherv (
         MPID_Datatype_get_extent_macro(recvtype, extent);
 
          MPID_Ensure_Aint_fits_in_pointer((
-            MPI_VOID_PTR_CAST_TO_MPI_AINT recvbuf + displs[rank] * extent));
+            MPIR_VOID_PTR_CAST_TO_MPI_AINT recvbuf + displs[rank] * extent));
         for (i=0; i<remote_comm_size; i++) {
             if (recvcnts[i]) {
                 mpi_errno = MPIC_Recv(((char *)recvbuf+displs[i]*extent), 
diff --git a/mpich2/src/mpi/coll/scatter.c b/mpich2/src/mpi/coll/scatter.c
index 937f79d..da28599 100644
--- a/mpich2/src/mpi/coll/scatter.c
+++ b/mpich2/src/mpi/coll/scatter.c
@@ -99,7 +99,7 @@ int MPIR_Scatter (
                recvcnt and recvtype are not valid */
             MPID_Datatype_get_size_macro(sendtype, sendtype_size);
             MPID_Ensure_Aint_fits_in_pointer(
-               (MPI_VOID_PTR_CAST_TO_MPI_AINT sendbuf + 
+               (MPIR_VOID_PTR_CAST_TO_MPI_AINT sendbuf + 
                   extent*sendcnt*comm_size));
 
             nbytes = sendtype_size * sendcnt;
@@ -514,7 +514,7 @@ int MPIR_Scatter_inter (
                 MPID_Datatype_get_extent_macro(recvtype, extent);
                MPID_Ensure_Aint_fits_in_pointer(extent*recvcnt*local_size);
                MPID_Ensure_Aint_fits_in_pointer(
-                  (MPI_VOID_PTR_CAST_TO_MPI_AINT sendbuf + 
+                  (MPIR_VOID_PTR_CAST_TO_MPI_AINT sendbuf + 
                   sendcnt*remote_size*extent));
 
                 tmp_buf =
diff --git a/mpich2/src/mpi/coll/scatterv.c b/mpich2/src/mpi/coll/scatterv.c
index b60a5c4..5c4ac20 100644
--- a/mpich2/src/mpi/coll/scatterv.c
+++ b/mpich2/src/mpi/coll/scatterv.c
@@ -79,7 +79,7 @@ int MPIR_Scatterv (
          * a minimal sanity check. maybe add a global var since we do loop over
          * sendcount[] in MPI_Scatterv before calling this*/
         MPID_Ensure_Aint_fits_in_pointer((
-         MPI_VOID_PTR_CAST_TO_MPI_AINT sendbuf + extent));
+         MPIR_VOID_PTR_CAST_TO_MPI_AINT sendbuf + extent));
 
         /* We could use Isend here, but since the receivers need to execute
            a simple Recv, it may not make much difference in performance, 
diff --git a/mpich2/src/mpi/datatype/address.c b/mpich2/src/mpi/datatype/address.c
index 5ce6263..80706c6 100644
--- a/mpich2/src/mpi/datatype/address.c
+++ b/mpich2/src/mpi/datatype/address.c
@@ -88,7 +88,7 @@ int MPI_Address( void *location, MPI_Aint *address )
        standard, I can't tell if this is a compiler bug or a language bug.
     */
 #ifdef CHAR_PTR_IS_ADDRESS
-    *address = MPI_VOID_PTR_CAST_TO_MPI_AINT ((char *)location);
+    *address = MPIR_VOID_PTR_CAST_TO_MPI_AINT ((char *)location);
 #else
     /* Note that this is the "portable" way to generate an address.
        The difference of two pointers is the number of elements
@@ -97,7 +97,7 @@ int MPI_Address( void *location, MPI_Aint *address )
        of bytes from 0 to location */
     /* To cover the case where a pointer is 32 bits and MPI_Aint is 64 bits,
        add cast to unsigned so the high order address bit is not sign-extended. */
-    *address = MPI_VOID_PTR_CAST_TO_MPI_AINT ((char *)location - (char *)MPI_BOTTOM);
+    *address = MPIR_VOID_PTR_CAST_TO_MPI_AINT ((char *)location - (char *)MPI_BOTTOM);
 #endif
     /* The same code is used in MPI_Get_address */
     
diff --git a/mpich2/src/mpi/datatype/get_address.c b/mpich2/src/mpi/datatype/get_address.c
index 9fdc911..a59eeff 100644
--- a/mpich2/src/mpi/datatype/get_address.c
+++ b/mpich2/src/mpi/datatype/get_address.c
@@ -98,14 +98,14 @@ int MPI_Get_address(void *location, MPI_Aint *address)
        standard, I can't tell if this is a compiler bug or a language bug.
     */
 #ifdef CHAR_PTR_IS_ADDRESS
-    *address = MPI_VOID_PTR_CAST_TO_MPI_AINT ((char *)location);
+    *address = MPIR_VOID_PTR_CAST_TO_MPI_AINT ((char *)location);
 #else
     /* Note that this is the "portable" way to generate an address.
        The difference of two pointers is the number of elements
        between them, so this gives the number of chars between location
        and ptr.  As long as sizeof(char) represents one byte, 
        of bytes from 0 to location */
-    *address = MPI_VOID_PTR_CAST_TO_MPI_AINT ((char *)location - (char *)MPI_BOTTOM);
+    *address = MPIR_VOID_PTR_CAST_TO_MPI_AINT ((char *)location - (char *)MPI_BOTTOM);
 #endif
     /* The same code is used in MPI_Address */
     
diff --git a/mpich2/src/mpi/datatype/pack.c b/mpich2/src/mpi/datatype/pack.c
index d7a27c6..3a247f1 100644
--- a/mpich2/src/mpi/datatype/pack.c
+++ b/mpich2/src/mpi/datatype/pack.c
@@ -191,7 +191,7 @@ int MPI_Pack(void *inbuf,
     last  = SEGMENT_IGNORE_LAST;
 
     /* Ensure that pointer increment fits in a pointer */
-    MPID_Ensure_Aint_fits_in_pointer( (MPI_VOID_PTR_CAST_TO_MPI_AINT outbuf) + (MPI_Aint)*position );
+    MPID_Ensure_Aint_fits_in_pointer( (MPIR_VOID_PTR_CAST_TO_MPI_AINT outbuf) + (MPI_Aint)*position );
 
     MPID_Segment_pack(segp,
 		      first,
diff --git a/mpich2/src/mpi/datatype/pack_external.c b/mpich2/src/mpi/datatype/pack_external.c
index e794c6a..6dbd570 100644
--- a/mpich2/src/mpi/datatype/pack_external.c
+++ b/mpich2/src/mpi/datatype/pack_external.c
@@ -135,7 +135,7 @@ int MPI_Pack_external(char *datarep,
     last  = SEGMENT_IGNORE_LAST;
 
     /* Ensure that pointer increment fits in a pointer */
-    MPID_Ensure_Aint_fits_in_pointer( (MPI_VOID_PTR_CAST_TO_MPI_AINT outbuf) + *position );
+    MPID_Ensure_Aint_fits_in_pointer( (MPIR_VOID_PTR_CAST_TO_MPI_AINT outbuf) + *position );
 
     MPID_Segment_pack_external32(segp,
 				 first,
@@ -159,7 +159,7 @@ int MPI_Pack_external(char *datarep,
 	mpi_errno = MPIR_Err_create_code(
 	    mpi_errno, MPIR_ERR_RECOVERABLE, FCNAME, __LINE__, MPI_ERR_OTHER, "**mpi_pack_external",
 	    "**mpi_pack_external %s %p %d %D %p %L %p", 
-	    datarep, inbuf, incount, datatype, outbuf, MPI_AINT_CAST_TO_LONG_LONG outcount, position);
+	    datarep, inbuf, incount, datatype, outbuf, MPIR_MPI_AINT_CAST_TO_LONG_LONG outcount, position);
     }
 #   endif
     mpi_errno = MPIR_Err_return_comm( 0, FCNAME, mpi_errno );
diff --git a/mpich2/src/mpi/datatype/type_create_hvector.c b/mpich2/src/mpi/datatype/type_create_hvector.c
index 2cfe2da..a35a0c5 100644
--- a/mpich2/src/mpi/datatype/type_create_hvector.c
+++ b/mpich2/src/mpi/datatype/type_create_hvector.c
@@ -125,7 +125,7 @@ int MPI_Type_create_hvector(int count,
 	    mpi_errno, MPIR_ERR_RECOVERABLE, FCNAME, __LINE__,
 	    MPI_ERR_OTHER, "**mpi_type_create_hvector",
 	    "**mpi_type_create_hvector %d %d %L %D %p", count,
-	    blocklength, MPI_AINT_CAST_TO_LONG_LONG stride, oldtype, newtype);
+	    blocklength, MPIR_MPI_AINT_CAST_TO_LONG_LONG stride, oldtype, newtype);
     }
 #   endif
     mpi_errno = MPIR_Err_return_comm( NULL, FCNAME, mpi_errno );
diff --git a/mpich2/src/mpi/datatype/type_create_resized.c b/mpich2/src/mpi/datatype/type_create_resized.c
index 991fe8d..c8b15c7 100644
--- a/mpich2/src/mpi/datatype/type_create_resized.c
+++ b/mpich2/src/mpi/datatype/type_create_resized.c
@@ -121,8 +121,8 @@ int MPI_Type_create_resized(MPI_Datatype oldtype,
 	mpi_errno = MPIR_Err_create_code(
 	    mpi_errno, MPIR_ERR_RECOVERABLE, FCNAME, __LINE__, MPI_ERR_OTHER, "**mpi_type_create_resized",
 	    "**mpi_type_create_resized %D %L %L %p", oldtype, 
-	    MPI_AINT_CAST_TO_LONG_LONG lb, 
-	    MPI_AINT_CAST_TO_LONG_LONG extent, 
+	    MPIR_MPI_AINT_CAST_TO_LONG_LONG lb, 
+	    MPIR_MPI_AINT_CAST_TO_LONG_LONG extent, 
 	    newtype);
     }
 #   endif
diff --git a/mpich2/src/mpi/datatype/type_hvector.c b/mpich2/src/mpi/datatype/type_hvector.c
index 8e6f87b..dc40877 100644
--- a/mpich2/src/mpi/datatype/type_hvector.c
+++ b/mpich2/src/mpi/datatype/type_hvector.c
@@ -121,7 +121,7 @@ int MPI_Type_hvector(int count,
 	mpi_errno = MPIR_Err_create_code(
 	    mpi_errno, MPIR_ERR_RECOVERABLE, FCNAME, __LINE__, MPI_ERR_OTHER, "**mpi_type_hvector",
 	    "**mpi_type_hvector %d %d %L %D %p", count, blocklen, 
-	    MPI_AINT_CAST_TO_LONG_LONG stride, 
+	    MPIR_MPI_AINT_CAST_TO_LONG_LONG stride, 
 	    old_type, newtype_p);
     }
 #   endif
diff --git a/mpich2/src/mpi/datatype/unpack.c b/mpich2/src/mpi/datatype/unpack.c
index cfc5048..50c55ce 100644
--- a/mpich2/src/mpi/datatype/unpack.c
+++ b/mpich2/src/mpi/datatype/unpack.c
@@ -134,7 +134,7 @@ int MPI_Unpack(void *inbuf, int insize, int *position,
     last  = SEGMENT_IGNORE_LAST;
 
     /* Ensure that pointer increment fits in a pointer */
-    MPID_Ensure_Aint_fits_in_pointer( (MPI_VOID_PTR_CAST_TO_MPI_AINT inbuf) + (MPI_Aint)*position );
+    MPID_Ensure_Aint_fits_in_pointer( (MPIR_VOID_PTR_CAST_TO_MPI_AINT inbuf) + (MPI_Aint)*position );
 
     MPID_Segment_unpack(segp,
 			first,
diff --git a/mpich2/src/mpi/datatype/unpack_external.c b/mpich2/src/mpi/datatype/unpack_external.c
index 9804cdc..6bea2f7 100644
--- a/mpich2/src/mpi/datatype/unpack_external.c
+++ b/mpich2/src/mpi/datatype/unpack_external.c
@@ -119,7 +119,7 @@ int MPI_Unpack_external(char *datarep,
     last  = SEGMENT_IGNORE_LAST;
 
     /* Ensure that pointer increment fits in a pointer */
-    MPID_Ensure_Aint_fits_in_pointer( (MPI_VOID_PTR_CAST_TO_MPI_AINT inbuf) + *position );
+    MPID_Ensure_Aint_fits_in_pointer( (MPIR_VOID_PTR_CAST_TO_MPI_AINT inbuf) + *position );
 
     MPID_Segment_unpack_external32(segp,
 				   first,
@@ -144,7 +144,7 @@ int MPI_Unpack_external(char *datarep,
 	mpi_errno = MPIR_Err_create_code(
 	    mpi_errno, MPIR_ERR_RECOVERABLE, FCNAME, __LINE__, MPI_ERR_OTHER, "**mpi_unpack_external",
 	    "**mpi_unpack_external %s %p %L %p %p %d %D", datarep, inbuf, 
-	    MPI_AINT_CAST_TO_LONG_LONG insize, 
+	    MPIR_MPI_AINT_CAST_TO_LONG_LONG insize, 
 	    position, outbuf, outcount, datatype);
     }
 #   endif
diff --git a/mpich2/src/mpi/rma/accumulate.c b/mpich2/src/mpi/rma/accumulate.c
index d563d8a..b4897a0 100644
--- a/mpich2/src/mpi/rma/accumulate.c
+++ b/mpich2/src/mpi/rma/accumulate.c
@@ -157,7 +157,7 @@ int MPI_Accumulate(void *origin_addr, int origin_count, MPI_Datatype
 	mpi_errno = MPIR_Err_create_code(
 	    mpi_errno, MPIR_ERR_RECOVERABLE, FCNAME, __LINE__, MPI_ERR_OTHER, "**mpi_accumulate",
 	    "**mpi_accumulate %p %d %D %d %L %d %D %O %W", origin_addr, origin_count, origin_datatype,
-	    target_rank, MPI_AINT_CAST_TO_LONG_LONG target_disp, target_count, target_datatype, op, win);
+	    target_rank, MPIR_MPI_AINT_CAST_TO_LONG_LONG target_disp, target_count, target_datatype, op, win);
     }
 #   endif
     mpi_errno = MPIR_Err_return_win( win_ptr, FCNAME, mpi_errno );
diff --git a/mpich2/src/mpi/rma/alloc_mem.c b/mpich2/src/mpi/rma/alloc_mem.c
index 330d884..f281bd6 100644
--- a/mpich2/src/mpi/rma/alloc_mem.c
+++ b/mpich2/src/mpi/rma/alloc_mem.c
@@ -113,7 +113,7 @@ int MPI_Alloc_mem(MPI_Aint size, MPI_Info info, void *baseptr)
     {
 	mpi_errno = MPIR_Err_create_code(
 	    mpi_errno, MPIR_ERR_RECOVERABLE, FCNAME, __LINE__, MPI_ERR_OTHER, "**mpi_alloc_mem",
-	    "**mpi_alloc_mem %L %I %p", MPI_AINT_CAST_TO_LONG_LONG size, info, baseptr);
+	    "**mpi_alloc_mem %L %I %p", MPIR_MPI_AINT_CAST_TO_LONG_LONG size, info, baseptr);
     }
 #   endif
     mpi_errno = MPIR_Err_return_comm( NULL, FCNAME, mpi_errno );
diff --git a/mpich2/src/mpi/rma/get.c b/mpich2/src/mpi/rma/get.c
index 71db17b..7c02488 100644
--- a/mpich2/src/mpi/rma/get.c
+++ b/mpich2/src/mpi/rma/get.c
@@ -153,7 +153,7 @@ int MPI_Get(void *origin_addr, int origin_count, MPI_Datatype
 	mpi_errno = MPIR_Err_create_code(
 	    mpi_errno, MPIR_ERR_RECOVERABLE, FCNAME, __LINE__, MPI_ERR_OTHER, "**mpi_get", "**mpi_get %p %d %D %d %L %d %D %W",
 	    origin_addr, origin_count, origin_datatype, target_rank, 
-       MPI_AINT_CAST_TO_LONG_LONG target_disp, target_count, target_datatype, win);
+       MPIR_MPI_AINT_CAST_TO_LONG_LONG target_disp, target_count, target_datatype, win);
     }
 #   endif
     mpi_errno = MPIR_Err_return_win( win_ptr, FCNAME, mpi_errno );
diff --git a/mpich2/src/mpi/rma/put.c b/mpich2/src/mpi/rma/put.c
index 7234b70..ee82f5b 100644
--- a/mpich2/src/mpi/rma/put.c
+++ b/mpich2/src/mpi/rma/put.c
@@ -153,7 +153,7 @@ int MPI_Put(void *origin_addr, int origin_count, MPI_Datatype
 	mpi_errno = MPIR_Err_create_code(
 	    mpi_errno, MPIR_ERR_RECOVERABLE, FCNAME, __LINE__, MPI_ERR_OTHER, "**mpi_put", "**mpi_put %p %d %D %d %L %d %D %W",
 	    origin_addr, origin_count, origin_datatype, target_rank, 
-      MPI_AINT_CAST_TO_LONG_LONG target_disp, target_count, target_datatype, win);
+      MPIR_MPI_AINT_CAST_TO_LONG_LONG target_disp, target_count, target_datatype, win);
     }
 #   endif
     mpi_errno = MPIR_Err_return_win( win_ptr, FCNAME, mpi_errno );
diff --git a/mpich2/src/mpi/rma/win_create.c b/mpich2/src/mpi/rma/win_create.c
index a2bc2b1..ba3f556 100644
--- a/mpich2/src/mpi/rma/win_create.c
+++ b/mpich2/src/mpi/rma/win_create.c
@@ -134,7 +134,7 @@ int MPI_Win_create(void *base, MPI_Aint size, int disp_unit, MPI_Info info,
     {
 	mpi_errno = MPIR_Err_create_code(
 	    mpi_errno, MPIR_ERR_RECOVERABLE, FCNAME, __LINE__, MPI_ERR_OTHER, "**mpi_win_create", 
-	    "**mpi_win_create %p %L %d %I %C %p", base, MPI_AINT_CAST_TO_LONG_LONG size, disp_unit, info, comm, win);
+	    "**mpi_win_create %p %L %d %I %C %p", base, MPIR_MPI_AINT_CAST_TO_LONG_LONG size, disp_unit, info, comm, win);
     }
 #   endif
     mpi_errno = MPIR_Err_return_comm( comm_ptr, FCNAME, mpi_errno );
diff --git a/mpich2/src/mpi/romio/adio/ad_bgl/ad_bgl_aggrs.c b/mpich2/src/mpi/romio/adio/ad_bgl/ad_bgl_aggrs.c
index 3812bc1..16a2d2c 100644
--- a/mpich2/src/mpi/romio/adio/ad_bgl/ad_bgl_aggrs.c
+++ b/mpich2/src/mpi/romio/adio/ad_bgl/ad_bgl_aggrs.c
@@ -886,9 +886,9 @@ void ADIOI_BGL_Calc_others_req(ADIO_File fd, int count_my_req_procs,
 	    others_req[i].lens = (int *)
 		ADIOI_Malloc(count_others_req_per_proc[i]*sizeof(int)); 
 
-	    if ( (MPI_Puint)others_req[i].offsets < (MPI_Puint)recvBufForOffsets )
+	    if ( (MPIR_Puint)others_req[i].offsets < (MPIR_Puint)recvBufForOffsets )
 		recvBufForOffsets = others_req[i].offsets;
-	    if ( (MPI_Puint)others_req[i].lens < (MPI_Puint)recvBufForLens )
+	    if ( (MPIR_Puint)others_req[i].lens < (MPIR_Puint)recvBufForLens )
 		recvBufForLens = others_req[i].lens;
 
 	    others_req[i].mem_ptrs = (MPI_Aint *)
@@ -917,11 +917,11 @@ void ADIOI_BGL_Calc_others_req(ADIO_File fd, int count_my_req_procs,
     for (i=0; i<nprocs; i++)
     {
 	if ( (my_req[i].count) &&
-	     ((MPI_Puint)my_req[i].offsets <= (MPI_Puint)sendBufForOffsets) )
+	     ((MPIR_Puint)my_req[i].offsets <= (MPIR_Puint)sendBufForOffsets) )
 	  sendBufForOffsets = my_req[i].offsets;
 	   
 	if ( (my_req[i].count) &&
-	     ((MPI_Puint)my_req[i].lens <= (MPI_Puint)sendBufForLens) )
+	     ((MPIR_Puint)my_req[i].lens <= (MPIR_Puint)sendBufForLens) )
 	    sendBufForLens = my_req[i].lens;
     }
 
@@ -938,9 +938,9 @@ void ADIOI_BGL_Calc_others_req(ADIO_File fd, int count_my_req_procs,
 	    sdispls[i] = 0;
 	else
   	  sdispls[i] =  (int)
-	                ( ( (MPI_Puint)my_req[i].offsets - 
-			   (MPI_Puint)sendBufForOffsets ) / 
-			  (MPI_Puint)sizeof(ADIO_Offset) );
+	                ( ( (MPIR_Puint)my_req[i].offsets - 
+			   (MPIR_Puint)sendBufForOffsets ) / 
+			  (MPIR_Puint)sizeof(ADIO_Offset) );
 
 	// Receive these offsets from process i.
 	rcounts[i] = count_others_req_per_proc[i];
@@ -948,9 +948,9 @@ void ADIOI_BGL_Calc_others_req(ADIO_File fd, int count_my_req_procs,
 	    rdispls[i] = 0;
 	else
 	    rdispls[i] = (int)
-	                 ( ( (MPI_Puint)others_req[i].offsets - 
-			     (MPI_Puint)recvBufForOffsets ) / 
-			   (MPI_Puint)sizeof(ADIO_Offset) );
+	                 ( ( (MPIR_Puint)others_req[i].offsets - 
+			     (MPIR_Puint)recvBufForOffsets ) / 
+			   (MPIR_Puint)sizeof(ADIO_Offset) );
     }
 
     /* Exchange the offsets */
@@ -972,9 +972,9 @@ void ADIOI_BGL_Calc_others_req(ADIO_File fd, int count_my_req_procs,
 	    sdispls[i] = 0;
 	else
 	  sdispls[i] = (int)
-	               ( ( (MPI_Puint)my_req[i].lens - 
-			   (MPI_Puint)sendBufForLens ) / 
-			 (MPI_Puint) sizeof(int) );
+	               ( ( (MPIR_Puint)my_req[i].lens - 
+			   (MPIR_Puint)sendBufForLens ) / 
+			 (MPIR_Puint) sizeof(int) );
 	
 	// Receive these offsets from process i.
 	rcounts[i] = count_others_req_per_proc[i];
@@ -982,9 +982,9 @@ void ADIOI_BGL_Calc_others_req(ADIO_File fd, int count_my_req_procs,
 	    rdispls[i] = 0;
 	else
 	    rdispls[i] = (int)
-	                 ( ( (MPI_Puint)others_req[i].lens - 
-			     (MPI_Puint)recvBufForLens ) / 
-			   (MPI_Puint) sizeof(int) );
+	                 ( ( (MPIR_Puint)others_req[i].lens - 
+			     (MPIR_Puint)recvBufForLens ) / 
+			   (MPIR_Puint) sizeof(int) );
     }
 
     /* Exchange the lengths */
diff --git a/mpich2/src/mpi/romio/adio/ad_bgl/ad_bgl_rdcoll.c b/mpich2/src/mpi/romio/adio/ad_bgl/ad_bgl_rdcoll.c
index e9c834f..ee7d8bb 100644
--- a/mpich2/src/mpi/romio/adio/ad_bgl/ad_bgl_rdcoll.c
+++ b/mpich2/src/mpi/romio/adio/ad_bgl/ad_bgl_rdcoll.c
@@ -587,7 +587,7 @@ static void ADIOI_Read_and_exch(ADIO_File fd, void *buf, MPI_Datatype
 		    }
 		    if (req_off < real_off + real_size) {
 			count[i]++;
-      ADIOI_Assert((((ADIO_Offset)(MPI_Puint)read_buf)+req_off-real_off) == (ADIO_Offset)(MPI_Puint)(read_buf+req_off-real_off));
+      ADIOI_Assert((((ADIO_Offset)(MPIR_Puint)read_buf)+req_off-real_off) == (ADIO_Offset)(MPIR_Puint)(read_buf+req_off-real_off));
 			MPI_Address(read_buf+req_off-real_off, 
                                &(others_req[i].mem_ptrs[j]));
       ADIOI_Assert((real_off + real_size - req_off) == (int)(real_off + real_size - req_off));
@@ -668,7 +668,7 @@ static void ADIOI_Read_and_exch(ADIO_File fd, void *buf, MPI_Datatype
 
 	if (for_next_iter) {
 	    tmp_buf = (char *) ADIOI_Malloc(for_next_iter);
-      ADIOI_Assert((((ADIO_Offset)(MPI_Puint)read_buf)+real_size-for_next_iter) == (ADIO_Offset)(MPI_Puint)(read_buf+real_size-for_next_iter));
+      ADIOI_Assert((((ADIO_Offset)(MPIR_Puint)read_buf)+real_size-for_next_iter) == (ADIO_Offset)(MPIR_Puint)(read_buf+real_size-for_next_iter));
       ADIOI_Assert((for_next_iter+coll_bufsize) == (size_t)(for_next_iter+coll_bufsize));
 	    memcpy(tmp_buf, read_buf+real_size-for_next_iter, for_next_iter);
 	    ADIOI_Free(read_buf);
@@ -888,7 +888,7 @@ static void ADIOI_Fill_user_buffer(ADIO_File fd, void *buf, ADIOI_Flatlist_node
 { \
     while (size) { \
 	size_in_buf = ADIOI_MIN(size, flat_buf_sz); \
-  ADIOI_Assert((((ADIO_Offset)(MPI_Puint)buf) + user_buf_idx) == (ADIO_Offset)(MPI_Puint)(buf + user_buf_idx)); \
+  ADIOI_Assert((((ADIO_Offset)(MPIR_Puint)buf) + user_buf_idx) == (ADIO_Offset)(MPIR_Puint)(buf + user_buf_idx)); \
   ADIOI_Assert(size_in_buf == (size_t)size_in_buf); \
 	memcpy(((char *) buf) + user_buf_idx, \
 	       &(recv_buf[p][recv_buf_idx[p]]), size_in_buf); \
diff --git a/mpich2/src/mpi/romio/adio/ad_bgl/ad_bgl_wrcoll.c b/mpich2/src/mpi/romio/adio/ad_bgl/ad_bgl_wrcoll.c
index f79ed35..12d22f4 100644
--- a/mpich2/src/mpi/romio/adio/ad_bgl/ad_bgl_wrcoll.c
+++ b/mpich2/src/mpi/romio/adio/ad_bgl/ad_bgl_wrcoll.c
@@ -552,7 +552,7 @@ static void ADIOI_Exch_and_write(ADIO_File fd, void *buf, MPI_Datatype
 		    }
 		    if (req_off < off + size) {
 			count[i]++;
-      ADIOI_Assert((((ADIO_Offset)(MPI_Puint)write_buf)+req_off-off) == (ADIO_Offset)(MPI_Puint)(write_buf+req_off-off));
+      ADIOI_Assert((((ADIO_Offset)(MPIR_Puint)write_buf)+req_off-off) == (ADIO_Offset)(MPIR_Puint)(write_buf+req_off-off));
 			MPI_Address(write_buf+req_off-off, 
                                &(others_req[i].mem_ptrs[j]));
       ADIOI_Assert((off + size - req_off) == (int)(off + size - req_off));
@@ -935,7 +935,7 @@ static void ADIOI_W_Exchange_data(ADIO_File fd, void *buf, char *write_buf,
 { \
     while (size) { \
         size_in_buf = ADIOI_MIN(size, flat_buf_sz); \
-  ADIOI_Assert((((ADIO_Offset)(MPI_Puint)buf) + user_buf_idx) == (ADIO_Offset)(MPI_Puint)(buf + user_buf_idx)); \
+  ADIOI_Assert((((ADIO_Offset)(MPIR_Puint)buf) + user_buf_idx) == (ADIO_Offset)(MPIR_Puint)(buf + user_buf_idx)); \
   ADIOI_Assert(size_in_buf == (size_t)size_in_buf); \
         memcpy(&(send_buf[p][send_buf_idx[p]]), \
                ((char *) buf) + user_buf_idx, size_in_buf); \
diff --git a/mpich2/src/mpi/romio/adio/common/ad_read_coll.c b/mpich2/src/mpi/romio/adio/common/ad_read_coll.c
index c6bd6e5..f5220a9 100644
--- a/mpich2/src/mpi/romio/adio/common/ad_read_coll.c
+++ b/mpich2/src/mpi/romio/adio/common/ad_read_coll.c
@@ -665,7 +665,7 @@ static void ADIOI_Read_and_exch(ADIO_File fd, void *buf, MPI_Datatype
 		    }
 		    if (req_off < real_off + real_size) {
 			count[i]++;
-      ADIOI_Assert((((ADIO_Offset)(MPI_Puint)read_buf)+req_off-real_off) == (ADIO_Offset)(MPI_Puint)(read_buf+req_off-real_off));
+      ADIOI_Assert((((ADIO_Offset)(MPIR_Puint)read_buf)+req_off-real_off) == (ADIO_Offset)(MPIR_Puint)(read_buf+req_off-real_off));
 			MPI_Address(read_buf+req_off-real_off, 
                                &(others_req[i].mem_ptrs[j]));
       ADIOI_Assert((real_off + real_size - req_off) == (int)(real_off + real_size - req_off));
@@ -718,7 +718,7 @@ static void ADIOI_Read_and_exch(ADIO_File fd, void *buf, MPI_Datatype
 
 	if (for_next_iter) {
 	    tmp_buf = (char *) ADIOI_Malloc(for_next_iter);
-      ADIOI_Assert((((ADIO_Offset)(MPI_Puint)read_buf)+real_size-for_next_iter) == (ADIO_Offset)(MPI_Puint)(read_buf+real_size-for_next_iter));
+      ADIOI_Assert((((ADIO_Offset)(MPIR_Puint)read_buf)+real_size-for_next_iter) == (ADIO_Offset)(MPIR_Puint)(read_buf+real_size-for_next_iter));
       ADIOI_Assert((for_next_iter+coll_bufsize) == (size_t)(for_next_iter+coll_bufsize));
 	    memcpy(tmp_buf, read_buf+real_size-for_next_iter, for_next_iter);
 	    ADIOI_Free(read_buf);
@@ -918,7 +918,7 @@ static void ADIOI_Fill_user_buffer(ADIO_File fd, void *buf, ADIOI_Flatlist_node
 { \
     while (size) { \
 	size_in_buf = ADIOI_MIN(size, flat_buf_sz); \
-  ADIOI_Assert((((ADIO_Offset)(MPI_Puint)buf) + user_buf_idx) == (ADIO_Offset)(MPI_Puint)(buf + user_buf_idx)); \
+  ADIOI_Assert((((ADIO_Offset)(MPIR_Puint)buf) + user_buf_idx) == (ADIO_Offset)(MPIR_Puint)(buf + user_buf_idx)); \
   ADIOI_Assert(size_in_buf == (size_t)size_in_buf); \
 	memcpy(((char *) buf) + user_buf_idx, \
 	       &(recv_buf[p][recv_buf_idx[p]]), size_in_buf); \
diff --git a/mpich2/src/mpi/romio/adio/common/ad_read_str_naive.c b/mpich2/src/mpi/romio/adio/common/ad_read_str_naive.c
index b377d96..be6c192 100644
--- a/mpich2/src/mpi/romio/adio/common/ad_read_str_naive.c
+++ b/mpich2/src/mpi/romio/adio/common/ad_read_str_naive.c
@@ -81,7 +81,7 @@ void ADIOI_GEN_ReadStrided_naive(ADIO_File fd, void *buf, int count,
 		req_off = off;
 		req_len = flat_buf->blocklens[b_index];
 
-    ADIOI_Assert((((ADIO_Offset)(MPI_Puint)buf) + userbuf_off) == (ADIO_Offset)(MPI_Puint)(buf + userbuf_off));
+    ADIOI_Assert((((ADIO_Offset)(MPIR_Puint)buf) + userbuf_off) == (ADIO_Offset)(MPIR_Puint)(buf + userbuf_off));
     ADIOI_Assert(req_len == (int) req_len);
 		ADIO_ReadContig(fd, 
 				(char *) buf + userbuf_off,
@@ -245,7 +245,7 @@ void ADIOI_GEN_ReadStrided_naive(ADIO_File fd, void *buf, int count,
 		    req_off = off;
 		    req_len = frd_size;
 
-        ADIOI_Assert((((ADIO_Offset)(MPI_Puint)buf) + userbuf_off) == (ADIO_Offset)(MPI_Puint)(buf + userbuf_off));
+        ADIOI_Assert((((ADIO_Offset)(MPIR_Puint)buf) + userbuf_off) == (ADIO_Offset)(MPIR_Puint)(buf + userbuf_off));
         ADIOI_Assert(req_len == (int) req_len);
 		    ADIO_ReadContig(fd, 
 				    (char *) buf + userbuf_off,
@@ -311,7 +311,7 @@ void ADIOI_GEN_ReadStrided_naive(ADIO_File fd, void *buf, int count,
 		    req_len = size;
 		    userbuf_off = i_offset;
 
-        ADIOI_Assert((((ADIO_Offset)(MPI_Puint)buf) + userbuf_off) == (ADIO_Offset)(MPI_Puint)(buf + userbuf_off));
+        ADIOI_Assert((((ADIO_Offset)(MPIR_Puint)buf) + userbuf_off) == (ADIO_Offset)(MPIR_Puint)(buf + userbuf_off));
         ADIOI_Assert(req_len == (int) req_len);
 		    ADIO_ReadContig(fd, 
 				    (char *) buf + userbuf_off,
diff --git a/mpich2/src/mpi/romio/adio/common/ad_write_coll.c b/mpich2/src/mpi/romio/adio/common/ad_write_coll.c
index f82405d..76e3a5e 100644
--- a/mpich2/src/mpi/romio/adio/common/ad_write_coll.c
+++ b/mpich2/src/mpi/romio/adio/common/ad_write_coll.c
@@ -447,7 +447,7 @@ static void ADIOI_Exch_and_write(ADIO_File fd, void *buf, MPI_Datatype
 		    }
 		    if (req_off < off + size) {
 			count[i]++;
-      ADIOI_Assert((((ADIO_Offset)(MPI_Puint)write_buf)+req_off-off) == (ADIO_Offset)(MPI_Puint)(write_buf+req_off-off));
+      ADIOI_Assert((((ADIO_Offset)(MPIR_Puint)write_buf)+req_off-off) == (ADIO_Offset)(MPIR_Puint)(write_buf+req_off-off));
 			MPI_Address(write_buf+req_off-off, 
                                &(others_req[i].mem_ptrs[j]));
       ADIOI_Assert((off + size - req_off) == (int)(off + size - req_off));
@@ -819,7 +819,7 @@ static void ADIOI_Fill_send_buffer(ADIO_File fd, void *buf, ADIOI_Flatlist_node
 { \
     while (size) { \
         size_in_buf = ADIOI_MIN(size, flat_buf_sz); \
-  ADIOI_Assert((((ADIO_Offset)(MPI_Puint)buf) + user_buf_idx) == (ADIO_Offset)(MPI_Puint)(buf + user_buf_idx)); \
+  ADIOI_Assert((((ADIO_Offset)(MPIR_Puint)buf) + user_buf_idx) == (ADIO_Offset)(MPIR_Puint)(buf + user_buf_idx)); \
   ADIOI_Assert(size_in_buf == (size_t)size_in_buf); \
         memcpy(&(send_buf[p][send_buf_idx[p]]), \
                ((char *) buf) + user_buf_idx, size_in_buf); \
diff --git a/mpich2/src/mpi/romio/adio/common/ad_write_nolock.c b/mpich2/src/mpi/romio/adio/common/ad_write_nolock.c
index c331ac8..5ff0897 100644
--- a/mpich2/src/mpi/romio/adio/common/ad_write_nolock.c
+++ b/mpich2/src/mpi/romio/adio/common/ad_write_nolock.c
@@ -139,7 +139,7 @@ void ADIOI_NOLOCK_WriteStrided(ADIO_File fd, void *buf, int count,
 				    flat_buf->blocklens[i]);
 #endif
         ADIOI_Assert(flat_buf->blocklens[i] == (unsigned)flat_buf->blocklens[i]);
-        ADIOI_Assert((((ADIO_Offset)(MPI_Puint)buf) + (ADIO_Offset)j*(ADIO_Offset)buftype_extent + flat_buf->indices[i]) == (ADIO_Offset)((MPI_Puint)buf + (ADIO_Offset)j*(ADIO_Offset)buftype_extent + flat_buf->indices[i]));
+        ADIOI_Assert((((ADIO_Offset)(MPIR_Puint)buf) + (ADIO_Offset)j*(ADIO_Offset)buftype_extent + flat_buf->indices[i]) == (ADIO_Offset)((MPIR_Puint)buf + (ADIO_Offset)j*(ADIO_Offset)buftype_extent + flat_buf->indices[i]));
 #ifdef ADIOI_MPE_LOGGING
 		    MPE_Log_event( ADIOI_MPE_write_a, 0, NULL );
 #endif
diff --git a/mpich2/src/mpi/romio/adio/common/ad_write_str_naive.c b/mpich2/src/mpi/romio/adio/common/ad_write_str_naive.c
index 38e47f9..abff76c 100644
--- a/mpich2/src/mpi/romio/adio/common/ad_write_str_naive.c
+++ b/mpich2/src/mpi/romio/adio/common/ad_write_str_naive.c
@@ -83,7 +83,7 @@ void ADIOI_GEN_WriteStrided_naive(ADIO_File fd, void *buf, int count,
 		req_len = flat_buf->blocklens[b_index];
 
     ADIOI_Assert(req_len == (int) req_len);
-    ADIOI_Assert((((ADIO_Offset)(MPI_Puint)buf) + userbuf_off) == (ADIO_Offset)(MPI_Puint)(buf + userbuf_off));
+    ADIOI_Assert((((ADIO_Offset)(MPIR_Puint)buf) + userbuf_off) == (ADIO_Offset)(MPIR_Puint)(buf + userbuf_off));
 		ADIO_WriteContig(fd, 
 				(char *) buf + userbuf_off,
 				(int)req_len, 
@@ -246,7 +246,7 @@ void ADIOI_GEN_WriteStrided_naive(ADIO_File fd, void *buf, int count,
 		    req_len = fwr_size;
 
         ADIOI_Assert(req_len == (int) req_len);
-        ADIOI_Assert((((ADIO_Offset)(MPI_Puint)buf) + userbuf_off) == (ADIO_Offset)(MPI_Puint)(buf + userbuf_off));
+        ADIOI_Assert((((ADIO_Offset)(MPIR_Puint)buf) + userbuf_off) == (ADIO_Offset)(MPIR_Puint)(buf + userbuf_off));
 		    ADIO_WriteContig(fd, 
 				    (char *) buf + userbuf_off,
 				    (int)req_len, 
@@ -312,7 +312,7 @@ void ADIOI_GEN_WriteStrided_naive(ADIO_File fd, void *buf, int count,
 		    userbuf_off = i_offset;
 
         ADIOI_Assert(req_len == (int) req_len);
-        ADIOI_Assert((((ADIO_Offset)(MPI_Puint)buf) + userbuf_off) == (ADIO_Offset)(MPI_Puint)(buf + userbuf_off));
+        ADIOI_Assert((((ADIO_Offset)(MPIR_Puint)buf) + userbuf_off) == (ADIO_Offset)(MPIR_Puint)(buf + userbuf_off));
 		    ADIO_WriteContig(fd, 
 				    (char *) buf + userbuf_off,
 				    (int)req_len, 
diff --git a/mpich2/src/mpi/romio/adio/include/adioi.h b/mpich2/src/mpi/romio/adio/include/adioi.h
index db30f92..eb38d0a 100644
--- a/mpich2/src/mpi/romio/adio/include/adioi.h
+++ b/mpich2/src/mpi/romio/adio/include/adioi.h
@@ -654,13 +654,13 @@ int  ADIOI_MPE_postwrite_b;
       to (possible) 4 byte ptr cast)                              */
 /* Should work even on 64bit or old 32bit configs                 */
   /* Use MPID_Ensure_Aint_fits_in_pointer from mpiutil.h and 
-         MPI_AINT_CAST_TO_VOID_PTR from configure (mpi.h) */
+         MPIR_MPI_AINT_CAST_TO_VOID_PTR from configure (mpi.h) */
   #include "mpiimpl.h"
 
-  #define ADIOI_AINT_CAST_TO_VOID_PTR MPI_AINT_CAST_TO_VOID_PTR
+  #define ADIOI_AINT_CAST_TO_VOID_PTR MPIR_MPI_AINT_CAST_TO_VOID_PTR
   /* The next two casts are only used when you don't want sign extension
      when casting a (possible 4 byte) aint to a (8 byte) long long or offset */
-  #define ADIOI_AINT_CAST_TO_LONG_LONG MPI_AINT_CAST_TO_LONG_LONG
+  #define ADIOI_AINT_CAST_TO_LONG_LONG MPIR_MPI_AINT_CAST_TO_LONG_LONG
   #define ADIOI_AINT_CAST_TO_OFFSET ADIOI_AINT_CAST_TO_LONG_LONG
 
   #define ADIOI_ENSURE_AINT_FITS_IN_PTR(aint_value) MPID_Ensure_Aint_fits_in_pointer(aint_value)
diff --git a/mpich2/src/mpid/common/datatype/dataloop/dataloop.c b/mpich2/src/mpid/common/datatype/dataloop/dataloop.c
index 054094b..7de4967 100644
--- a/mpich2/src/mpid/common/datatype/dataloop/dataloop.c
+++ b/mpich2/src/mpid/common/datatype/dataloop/dataloop.c
@@ -155,11 +155,11 @@ void PREPEND_PREFIX(Dataloop_update)(DLOOP_Dataloop *dataloop,
 
 	    if (dataloop->loop_params.cm_t.dataloop)
 	    {
-		MPID_Ensure_Aint_fits_in_pointer(MPI_VOID_PTR_CAST_TO_MPI_AINT (char *) dataloop->loop_params.cm_t.dataloop + ptrdiff); 
+		MPID_Ensure_Aint_fits_in_pointer(MPIR_VOID_PTR_CAST_TO_MPI_AINT (char *) dataloop->loop_params.cm_t.dataloop + ptrdiff); 
 
 		dataloop->loop_params.cm_t.dataloop = 
-		    (DLOOP_Dataloop *) MPI_AINT_CAST_TO_VOID_PTR
-		    (MPI_VOID_PTR_CAST_TO_MPI_AINT (char *) dataloop->loop_params.cm_t.dataloop + ptrdiff);
+		    (DLOOP_Dataloop *) MPIR_MPI_AINT_CAST_TO_VOID_PTR
+		    (MPIR_VOID_PTR_CAST_TO_MPI_AINT (char *) dataloop->loop_params.cm_t.dataloop + ptrdiff);
 	    }
 
 	    if (!(dataloop->kind & DLOOP_FINAL_MASK))
@@ -169,18 +169,18 @@ void PREPEND_PREFIX(Dataloop_update)(DLOOP_Dataloop *dataloop,
 	case DLOOP_KIND_BLOCKINDEXED:
 	    if (dataloop->loop_params.bi_t.offset_array)
 	    {
-		MPID_Ensure_Aint_fits_in_pointer(MPI_VOID_PTR_CAST_TO_MPI_AINT (char *) dataloop->loop_params.bi_t.offset_array + ptrdiff);
+		MPID_Ensure_Aint_fits_in_pointer(MPIR_VOID_PTR_CAST_TO_MPI_AINT (char *) dataloop->loop_params.bi_t.offset_array + ptrdiff);
 		dataloop->loop_params.bi_t.offset_array = 
-		    (DLOOP_Offset *) MPI_AINT_CAST_TO_VOID_PTR
-		    (MPI_VOID_PTR_CAST_TO_MPI_AINT (char *) dataloop->loop_params.bi_t.offset_array + ptrdiff);
+		    (DLOOP_Offset *) MPIR_MPI_AINT_CAST_TO_VOID_PTR
+		    (MPIR_VOID_PTR_CAST_TO_MPI_AINT (char *) dataloop->loop_params.bi_t.offset_array + ptrdiff);
 	    }
 
 	    if (dataloop->loop_params.bi_t.dataloop)
 	    {
-		MPID_Ensure_Aint_fits_in_pointer(MPI_VOID_PTR_CAST_TO_MPI_AINT (char *) dataloop->loop_params.bi_t.dataloop + ptrdiff);
+		MPID_Ensure_Aint_fits_in_pointer(MPIR_VOID_PTR_CAST_TO_MPI_AINT (char *) dataloop->loop_params.bi_t.dataloop + ptrdiff);
 		dataloop->loop_params.bi_t.dataloop = 
-		    (DLOOP_Dataloop *) MPI_AINT_CAST_TO_VOID_PTR
-		    (MPI_VOID_PTR_CAST_TO_MPI_AINT (char *) dataloop->loop_params.bi_t.dataloop + ptrdiff);
+		    (DLOOP_Dataloop *) MPIR_MPI_AINT_CAST_TO_VOID_PTR
+		    (MPIR_VOID_PTR_CAST_TO_MPI_AINT (char *) dataloop->loop_params.bi_t.dataloop + ptrdiff);
 	    }
 
 	    if (!(dataloop->kind & DLOOP_FINAL_MASK))
@@ -190,26 +190,26 @@ void PREPEND_PREFIX(Dataloop_update)(DLOOP_Dataloop *dataloop,
 	case DLOOP_KIND_INDEXED:
 	    if (dataloop->loop_params.i_t.blocksize_array)
 	    {
-		MPID_Ensure_Aint_fits_in_pointer(MPI_VOID_PTR_CAST_TO_MPI_AINT (char *) dataloop->loop_params.i_t.blocksize_array + ptrdiff);
+		MPID_Ensure_Aint_fits_in_pointer(MPIR_VOID_PTR_CAST_TO_MPI_AINT (char *) dataloop->loop_params.i_t.blocksize_array + ptrdiff);
 		dataloop->loop_params.i_t.blocksize_array = 
-		    (DLOOP_Count *) MPI_AINT_CAST_TO_VOID_PTR
-		    (MPI_VOID_PTR_CAST_TO_MPI_AINT (char *) dataloop->loop_params.i_t.blocksize_array + ptrdiff);
+		    (DLOOP_Count *) MPIR_MPI_AINT_CAST_TO_VOID_PTR
+		    (MPIR_VOID_PTR_CAST_TO_MPI_AINT (char *) dataloop->loop_params.i_t.blocksize_array + ptrdiff);
 	    }
 
 	    if (dataloop->loop_params.i_t.offset_array)
 	    {
-		MPID_Ensure_Aint_fits_in_pointer(MPI_VOID_PTR_CAST_TO_MPI_AINT (char *) dataloop->loop_params.i_t.offset_array + ptrdiff);
+		MPID_Ensure_Aint_fits_in_pointer(MPIR_VOID_PTR_CAST_TO_MPI_AINT (char *) dataloop->loop_params.i_t.offset_array + ptrdiff);
 		dataloop->loop_params.i_t.offset_array = 
-		    (DLOOP_Offset *) MPI_AINT_CAST_TO_VOID_PTR
-		    (MPI_VOID_PTR_CAST_TO_MPI_AINT (char *) dataloop->loop_params.i_t.offset_array + ptrdiff);
+		    (DLOOP_Offset *) MPIR_MPI_AINT_CAST_TO_VOID_PTR
+		    (MPIR_VOID_PTR_CAST_TO_MPI_AINT (char *) dataloop->loop_params.i_t.offset_array + ptrdiff);
 	    }
 
 	    if (dataloop->loop_params.i_t.dataloop)
 	    {
-		MPID_Ensure_Aint_fits_in_pointer(MPI_VOID_PTR_CAST_TO_MPI_AINT (char *) dataloop->loop_params.i_t.dataloop + ptrdiff);
+		MPID_Ensure_Aint_fits_in_pointer(MPIR_VOID_PTR_CAST_TO_MPI_AINT (char *) dataloop->loop_params.i_t.dataloop + ptrdiff);
 		dataloop->loop_params.i_t.dataloop = 
-		    (DLOOP_Dataloop *) MPI_AINT_CAST_TO_VOID_PTR
-		    (MPI_VOID_PTR_CAST_TO_MPI_AINT (char *) dataloop->loop_params.i_t.dataloop + ptrdiff);
+		    (DLOOP_Dataloop *) MPIR_MPI_AINT_CAST_TO_VOID_PTR
+		    (MPIR_VOID_PTR_CAST_TO_MPI_AINT (char *) dataloop->loop_params.i_t.dataloop + ptrdiff);
 	    }
 
 	    if (!(dataloop->kind & DLOOP_FINAL_MASK))
@@ -219,26 +219,26 @@ void PREPEND_PREFIX(Dataloop_update)(DLOOP_Dataloop *dataloop,
 	case DLOOP_KIND_STRUCT:
 	    if (dataloop->loop_params.s_t.blocksize_array)
 	    {
-		MPID_Ensure_Aint_fits_in_pointer(MPI_VOID_PTR_CAST_TO_MPI_AINT (char *) dataloop->loop_params.s_t.blocksize_array + ptrdiff);
+		MPID_Ensure_Aint_fits_in_pointer(MPIR_VOID_PTR_CAST_TO_MPI_AINT (char *) dataloop->loop_params.s_t.blocksize_array + ptrdiff);
 		dataloop->loop_params.s_t.blocksize_array = 
-		    (DLOOP_Count *) MPI_AINT_CAST_TO_VOID_PTR
-		    (MPI_VOID_PTR_CAST_TO_MPI_AINT (char *) dataloop->loop_params.s_t.blocksize_array + ptrdiff);
+		    (DLOOP_Count *) MPIR_MPI_AINT_CAST_TO_VOID_PTR
+		    (MPIR_VOID_PTR_CAST_TO_MPI_AINT (char *) dataloop->loop_params.s_t.blocksize_array + ptrdiff);
 	    }
 
 	    if (dataloop->loop_params.s_t.offset_array)
 	    {
-		MPID_Ensure_Aint_fits_in_pointer(MPI_VOID_PTR_CAST_TO_MPI_AINT (char *) dataloop->loop_params.s_t.offset_array + ptrdiff);
+		MPID_Ensure_Aint_fits_in_pointer(MPIR_VOID_PTR_CAST_TO_MPI_AINT (char *) dataloop->loop_params.s_t.offset_array + ptrdiff);
 		dataloop->loop_params.s_t.offset_array = 
-		    (DLOOP_Offset *) MPI_AINT_CAST_TO_VOID_PTR
-		    (MPI_VOID_PTR_CAST_TO_MPI_AINT (char *) dataloop->loop_params.s_t.offset_array + ptrdiff);
+		    (DLOOP_Offset *) MPIR_MPI_AINT_CAST_TO_VOID_PTR
+		    (MPIR_VOID_PTR_CAST_TO_MPI_AINT (char *) dataloop->loop_params.s_t.offset_array + ptrdiff);
 	    }
 
 	    if (dataloop->loop_params.s_t.dataloop_array)
 	    {
-		MPID_Ensure_Aint_fits_in_pointer(MPI_VOID_PTR_CAST_TO_MPI_AINT (char *) dataloop->loop_params.s_t.dataloop_array + ptrdiff);
+		MPID_Ensure_Aint_fits_in_pointer(MPIR_VOID_PTR_CAST_TO_MPI_AINT (char *) dataloop->loop_params.s_t.dataloop_array + ptrdiff);
 		dataloop->loop_params.s_t.dataloop_array = 
-		    (DLOOP_Dataloop **) MPI_AINT_CAST_TO_VOID_PTR
-		    (MPI_VOID_PTR_CAST_TO_MPI_AINT (char *) dataloop->loop_params.s_t.dataloop_array + ptrdiff);
+		    (DLOOP_Dataloop **) MPIR_MPI_AINT_CAST_TO_VOID_PTR
+		    (MPIR_VOID_PTR_CAST_TO_MPI_AINT (char *) dataloop->loop_params.s_t.dataloop_array + ptrdiff);
 	    }
 
 	    /* fix the N dataloop pointers too */
@@ -246,9 +246,9 @@ void PREPEND_PREFIX(Dataloop_update)(DLOOP_Dataloop *dataloop,
 	    for (i=0; i < dataloop->loop_params.s_t.count; i++) {
 		if (looparray[i])
 		{
-		    MPID_Ensure_Aint_fits_in_pointer(MPI_VOID_PTR_CAST_TO_MPI_AINT (char *) looparray[i] + ptrdiff);
-		    looparray[i] = (DLOOP_Dataloop *) MPI_AINT_CAST_TO_VOID_PTR
-			(MPI_VOID_PTR_CAST_TO_MPI_AINT (char *) looparray[i] + ptrdiff);
+		    MPID_Ensure_Aint_fits_in_pointer(MPIR_VOID_PTR_CAST_TO_MPI_AINT (char *) looparray[i] + ptrdiff);
+		    looparray[i] = (DLOOP_Dataloop *) MPIR_MPI_AINT_CAST_TO_VOID_PTR
+			(MPIR_VOID_PTR_CAST_TO_MPI_AINT (char *) looparray[i] + ptrdiff);
 		}
 	    }
 
diff --git a/mpich2/src/mpid/common/datatype/dataloop/dataloop_create_pairtype.c b/mpich2/src/mpid/common/datatype/dataloop/dataloop_create_pairtype.c
index d5f7b86..11c7a7a 100644
--- a/mpich2/src/mpid/common/datatype/dataloop/dataloop_create_pairtype.c
+++ b/mpich2/src/mpid/common/datatype/dataloop/dataloop_create_pairtype.c
@@ -11,7 +11,7 @@
     {									\
 	struct { ut1_ a; ut2_ b; } foo;					\
 	disps[0] = 0;							\
-	disps[1] = MPI_VOID_PTR_CAST_TO_MPI_AINT ((char *) &foo.b - (char *) &foo.a);	\
+	disps[1] = MPIR_VOID_PTR_CAST_TO_MPI_AINT ((char *) &foo.b - (char *) &foo.a);	\
 	types[0] = mt1_;						\
 	types[1] = mt2_;						\
     }
diff --git a/mpich2/src/mpid/common/datatype/dataloop/dataloop_create_struct.c b/mpich2/src/mpid/common/datatype/dataloop/dataloop_create_struct.c
index d9fc694..50fe3c7 100644
--- a/mpich2/src/mpid/common/datatype/dataloop/dataloop_create_struct.c
+++ b/mpich2/src/mpid/common/datatype/dataloop/dataloop_create_struct.c
@@ -622,7 +622,7 @@ static int DLOOP_Dataloop_create_flattened_struct(int count,
 	 */
 	if (oldtypes[i] != MPI_UB && oldtypes[i] != MPI_LB && blklens[i] != 0)
 	{
-	    PREPEND_PREFIX(Segment_init)((char *) MPI_AINT_CAST_TO_VOID_PTR disps[i],
+	    PREPEND_PREFIX(Segment_init)((char *) MPIR_MPI_AINT_CAST_TO_VOID_PTR disps[i],
 					 (DLOOP_Count) blklens[i],
 					 oldtypes[i],
 					 segp,
diff --git a/mpich2/src/mpid/common/datatype/dataloop/veccpy.h b/mpich2/src/mpid/common/datatype/dataloop/veccpy.h
index 04a4858..4f7d602 100644
--- a/mpich2/src/mpid/common/datatype/dataloop/veccpy.h
+++ b/mpich2/src/mpid/common/datatype/dataloop/veccpy.h
@@ -11,20 +11,20 @@
 #ifdef HAVE_ANY_INT64_T_ALIGNEMENT
 #define MPIR_ALIGN8_TEST(p1,p2)
 #else
-#define MPIR_ALIGN8_TEST(p1,p2) && (((MPI_VOID_PTR_CAST_TO_MPI_AINT p1 | MPI_VOID_PTR_CAST_TO_MPI_AINT p2) & 0x7) == 0)
+#define MPIR_ALIGN8_TEST(p1,p2) && (((MPIR_VOID_PTR_CAST_TO_MPI_AINT p1 | MPIR_VOID_PTR_CAST_TO_MPI_AINT p2) & 0x7) == 0)
 #endif
 
 #ifdef HAVE_ANY_INT32_T_ALIGNEMENT
 #define MPIR_ALIGN4_TEST(p1,p2)
 #else
-#define MPIR_ALIGN4_TEST(p1,p2) && (((MPI_VOID_PTR_CAST_TO_MPI_AINT p1 | MPI_VOID_PTR_CAST_TO_MPI_AINT p2) & 0x3) == 0)
+#define MPIR_ALIGN4_TEST(p1,p2) && (((MPIR_VOID_PTR_CAST_TO_MPI_AINT p1 | MPIR_VOID_PTR_CAST_TO_MPI_AINT p2) & 0x3) == 0)
 #endif
 
 #define MPIDI_COPY_FROM_VEC(src,dest,stride,type,nelms,count) \
 { \
     if (!nelms) { \
-        src = (char*) MPI_AINT_CAST_TO_VOID_PTR                        \
-                      ((MPI_VOID_PTR_CAST_TO_MPI_AINT (src)) +         \
+        src = (char*) MPIR_MPI_AINT_CAST_TO_VOID_PTR                        \
+                      ((MPIR_VOID_PTR_CAST_TO_MPI_AINT (src)) +         \
 		       ((DLOOP_Offset)count * (DLOOP_Offset)stride) ); \
     } \
     else if (stride % sizeof(type)) { \
@@ -38,8 +38,8 @@
 #define MPIDI_COPY_TO_VEC(src,dest,stride,type,nelms,count) \
 { \
     if (!nelms) { \
-        dest = (char*) MPI_AINT_CAST_TO_VOID_PTR                        \
-                       ((MPI_VOID_PTR_CAST_TO_MPI_AINT (dest)) +        \
+        dest = (char*) MPIR_MPI_AINT_CAST_TO_VOID_PTR                        \
+                       ((MPIR_VOID_PTR_CAST_TO_MPI_AINT (dest)) +        \
                         ((DLOOP_Offset)count * (DLOOP_Offset)stride) ); \
     } \
     else if (stride % (DLOOP_Offset)sizeof(type)) { \
diff --git a/mpich2/src/mpid/common/datatype/mpid_segment.c b/mpich2/src/mpid/common/datatype/mpid_segment.c
index e478949..2210d61 100644
--- a/mpich2/src/mpid/common/datatype/mpid_segment.c
+++ b/mpich2/src/mpid/common/datatype/mpid_segment.c
@@ -248,7 +248,7 @@ static int MPID_Segment_contig_pack_to_iov(DLOOP_Offset *blocks_p,
 	    paramp->u.pack_vector.vectorp[last_idx].DLOOP_VECTOR_LEN;
     }
     
-    MPID_Ensure_Aint_fits_in_pointer( (MPI_VOID_PTR_CAST_TO_MPI_AINT (bufp)) + rel_off );
+    MPID_Ensure_Aint_fits_in_pointer( (MPIR_VOID_PTR_CAST_TO_MPI_AINT (bufp)) + rel_off );
     if ((last_idx == paramp->u.pack_vector.length-1) &&
 	(last_end != ((char *) bufp + rel_off)))
     {
@@ -346,7 +346,7 @@ static int MPID_Segment_vector_pack_to_iov(DLOOP_Offset *blocks_p,
 		paramp->u.pack_vector.vectorp[last_idx].DLOOP_VECTOR_LEN;
 	}
 
-	MPID_Ensure_Aint_fits_in_pointer( (MPI_VOID_PTR_CAST_TO_MPI_AINT (bufp)) + rel_off );
+	MPID_Ensure_Aint_fits_in_pointer( (MPIR_VOID_PTR_CAST_TO_MPI_AINT (bufp)) + rel_off );
 	if ((last_idx == paramp->u.pack_vector.length-1) &&
 	    (last_end != ((char *) bufp + rel_off)))
 	{
@@ -423,13 +423,13 @@ static int MPID_Segment_contig_flatten(DLOOP_Offset *blocks_p,
 #ifdef MPID_SP_VERBOSE
     MPIU_dbg_printf("\t[contig flatten: index = %d, loc = (" MPI_AINT_FMT_HEX_SPEC " + " MPI_AINT_FMT_HEX_SPEC ") = " MPI_AINT_FMT_HEX_SPEC ", size = " MPI_AINT_FMT_DEC_SPEC "]\n",
 		    index,
-		    MPI_VOID_PTR_CAST_TO_MPI_AINT bufp,
+		    MPIR_VOID_PTR_CAST_TO_MPI_AINT bufp,
 		    (MPI_Aint) rel_off,
-		    MPI_VOID_PTR_CAST_TO_MPI_AINT bufp + rel_off,
+		    MPIR_VOID_PTR_CAST_TO_MPI_AINT bufp + rel_off,
 		    (MPI_Aint) size);
 #endif
     
-    if (index > 0 && ((DLOOP_Offset) MPI_VOID_PTR_CAST_TO_MPI_AINT bufp + rel_off) ==
+    if (index > 0 && ((DLOOP_Offset) MPIR_VOID_PTR_CAST_TO_MPI_AINT bufp + rel_off) ==
 	((paramp->u.flatten.offp[index - 1]) +
 	 (DLOOP_Offset)paramp->u.flatten.sizep[index - 1]))
     {
@@ -437,7 +437,7 @@ static int MPID_Segment_contig_flatten(DLOOP_Offset *blocks_p,
 	paramp->u.flatten.sizep[index - 1] += size;
     }
     else {
-	paramp->u.flatten.offp[index] =  ((int64_t) MPI_VOID_PTR_CAST_TO_MPI_AINT bufp) + (int64_t) rel_off;
+	paramp->u.flatten.offp[index] =  ((int64_t) MPIR_VOID_PTR_CAST_TO_MPI_AINT bufp) + (int64_t) rel_off;
 	paramp->u.flatten.sizep[index] = size;
 
 	paramp->u.flatten.index++;
@@ -500,7 +500,7 @@ static int MPID_Segment_vector_flatten(DLOOP_Offset *blocks_p,
 	    blocks_left = 0;
 	}
 
-	if (index > 0 && ((DLOOP_Offset) MPI_VOID_PTR_CAST_TO_MPI_AINT bufp + rel_off) ==
+	if (index > 0 && ((DLOOP_Offset) MPIR_VOID_PTR_CAST_TO_MPI_AINT bufp + rel_off) ==
 	    ((paramp->u.flatten.offp[index - 1]) + (DLOOP_Offset)paramp->u.flatten.sizep[index - 1]))
 	{
 	    /* add this size to the last region rather than using up another one */
@@ -508,7 +508,7 @@ static int MPID_Segment_vector_flatten(DLOOP_Offset *blocks_p,
 	}
 	else if (index < paramp->u.flatten.length) {
 	    /* take up another region */
-	    paramp->u.flatten.offp[index]  = (DLOOP_Offset) MPI_VOID_PTR_CAST_TO_MPI_AINT bufp + rel_off;
+	    paramp->u.flatten.offp[index]  = (DLOOP_Offset) MPIR_VOID_PTR_CAST_TO_MPI_AINT bufp + rel_off;
 	    paramp->u.flatten.sizep[index] = size;
 	    paramp->u.flatten.index++;
 	}
diff --git a/mpich2/src/mpid/common/datatype/mpid_type_create_pairtype.c b/mpich2/src/mpid/common/datatype/mpid_type_create_pairtype.c
index e509101..99f2ec7 100644
--- a/mpich2/src/mpid/common/datatype/mpid_type_create_pairtype.c
+++ b/mpich2/src/mpid/common/datatype/mpid_type_create_pairtype.c
@@ -19,7 +19,7 @@
 	type_size   = sizeof(foo.a) + sizeof(foo.b);			\
 	type_extent = (MPI_Aint) sizeof(foo);				\
 	el_size = (sizeof(foo.a) == sizeof(foo.b)) ? (int) sizeof(foo.a) : -1; \
-	true_ub = (MPI_VOID_PTR_CAST_TO_MPI_AINT ((char *) &foo.b -     \
+	true_ub = (MPIR_VOID_PTR_CAST_TO_MPI_AINT ((char *) &foo.b -     \
                                                   (char *) &foo.a)) +   \
                   (MPI_Aint) sizeof(foo.b);                             \
 	alignsize = MPIR_MAX(MPID_Datatype_get_basic_size(mt1_),	\
diff --git a/mpich2/src/mpid/dcmfd/src/coll/allgather/mpido_allgather.c b/mpich2/src/mpid/dcmfd/src/coll/allgather/mpido_allgather.c
index 98b40a7..425150d 100644
--- a/mpich2/src/mpid/dcmfd/src/coll/allgather/mpido_allgather.c
+++ b/mpich2/src/mpid/dcmfd/src/coll/allgather/mpido_allgather.c
@@ -90,7 +90,7 @@ int MPIDO_Allgather_Async_bcast(void *sendbuf,
                            dt_true_lb);
 
    MPID_Ensure_Aint_fits_in_pointer (
-      (MPI_VOID_PTR_CAST_TO_MPI_AINT recvbuf + 
+      (MPIR_VOID_PTR_CAST_TO_MPI_AINT recvbuf + 
          comm_ptr->local_size * recvcount * extent));
 
    if (sendbuf != MPI_IN_PLACE)
@@ -169,7 +169,7 @@ int MPIDO_Allgather_Bcast(void *sendbuf,
    MPI_Aint extent;
    MPID_Datatype_get_extent_macro(recvtype, extent);
    MPID_Ensure_Aint_fits_in_pointer (
-      (MPI_VOID_PTR_CAST_TO_MPI_AINT recvbuf + 
+      (MPIR_VOID_PTR_CAST_TO_MPI_AINT recvbuf + 
          comm_ptr->local_size * recvcount * extent));
 
    if (sendbuf != MPI_IN_PLACE)
@@ -322,14 +322,14 @@ MPIDO_Allgather(void *sendbuf,
                             dt_null,
                             send_true_lb);
       MPID_Ensure_Aint_fits_in_pointer (
-         (MPI_VOID_PTR_CAST_TO_MPI_AINT sendbuf + send_true_lb));
+         (MPIR_VOID_PTR_CAST_TO_MPI_AINT sendbuf + send_true_lb));
    }
 
    config.largecount = (sendcount>32768);
 
    /* Needed in alltoall/allreduce implementations */
    MPID_Ensure_Aint_fits_in_pointer (
-      (MPI_VOID_PTR_CAST_TO_MPI_AINT recvbuf + 
+      (MPIR_VOID_PTR_CAST_TO_MPI_AINT recvbuf + 
          recv_true_lb + comm_ptr->local_size*send_size));
 
    /* verify everyone's datatype contiguity */
diff --git a/mpich2/src/mpid/dcmfd/src/coll/allgatherv/mpido_allgatherv.c b/mpich2/src/mpid/dcmfd/src/coll/allgatherv/mpido_allgatherv.c
index 1c423aa..7936ec4 100644
--- a/mpich2/src/mpid/dcmfd/src/coll/allgatherv/mpido_allgatherv.c
+++ b/mpich2/src/mpid/dcmfd/src/coll/allgatherv/mpido_allgatherv.c
@@ -110,7 +110,7 @@ int MPIDO_Allgatherv_Async_bcast(void *sendbuf,
    dt_true_lb);
       
    MPID_Ensure_Aint_fits_in_pointer (
-   (MPI_VOID_PTR_CAST_TO_MPI_AINT recvbuf +
+   (MPIR_VOID_PTR_CAST_TO_MPI_AINT recvbuf +
    displs[comm_ptr->rank] * extent));
    
    if(sendbuf != MPI_IN_PLACE)
@@ -203,7 +203,7 @@ int MPIDO_Allgatherv_Bcast(void *sendbuf,
    /* This isn't technically big enough, but we don't want to
     * add an assert inside the loop */
    MPID_Ensure_Aint_fits_in_pointer (
-      (MPI_VOID_PTR_CAST_TO_MPI_AINT recvbuf + 
+      (MPIR_VOID_PTR_CAST_TO_MPI_AINT recvbuf + 
          displs[comm_ptr->rank] * extent));
 
    if (sendbuf != MPI_IN_PLACE)
@@ -355,7 +355,7 @@ MPIDO_Allgatherv(void *sendbuf,
                               dt_null,
                               send_true_lb);
       MPID_Ensure_Aint_fits_in_pointer(
-            (MPI_VOID_PTR_CAST_TO_MPI_AINT sendbuf + send_true_lb));
+            (MPIR_VOID_PTR_CAST_TO_MPI_AINT sendbuf + send_true_lb));
    }
 
    int buffer_sum = 0;
@@ -387,7 +387,7 @@ MPIDO_Allgatherv(void *sendbuf,
                       comm_ptr);
    }
    MPID_Ensure_Aint_fits_in_pointer(
-         (MPI_VOID_PTR_CAST_TO_MPI_AINT recvbuf + recv_true_lb + buffer_sum));
+         (MPIR_VOID_PTR_CAST_TO_MPI_AINT recvbuf + recv_true_lb + buffer_sum));
 
    /* determine which protocol to use */
    /* 1) Tree allreduce
diff --git a/mpich2/src/mpid/dcmfd/src/coll/allreduce/mpido_allreduce.c b/mpich2/src/mpid/dcmfd/src/coll/allreduce/mpido_allreduce.c
index 6cf6748..1800148 100644
--- a/mpich2/src/mpid/dcmfd/src/coll/allreduce/mpido_allreduce.c
+++ b/mpich2/src/mpid/dcmfd/src/coll/allreduce/mpido_allreduce.c
@@ -321,7 +321,7 @@ int MPIDO_Allreduce(
                            dt_ptr,
                            dt_true_lb);
 
-   MPID_Ensure_Aint_fits_in_pointer(MPI_VOID_PTR_CAST_TO_MPI_AINT recvbuf +
+   MPID_Ensure_Aint_fits_in_pointer(MPIR_VOID_PTR_CAST_TO_MPI_AINT recvbuf +
                                    dt_true_lb);
    recvbuf = ((char *)recvbuf + dt_true_lb);
 
@@ -349,7 +349,7 @@ int MPIDO_Allreduce(
 
    if(sendbuf != MPI_IN_PLACE)
    {
-      MPID_Ensure_Aint_fits_in_pointer(MPI_VOID_PTR_CAST_TO_MPI_AINT sendbuf +
+      MPID_Ensure_Aint_fits_in_pointer(MPIR_VOID_PTR_CAST_TO_MPI_AINT sendbuf +
                                        dt_true_lb);
       sendbuf = ((char *)sendbuf + dt_true_lb);
      //      int err =
diff --git a/mpich2/src/mpid/dcmfd/src/coll/alltoall/mpido_alltoall.c b/mpich2/src/mpid/dcmfd/src/coll/alltoall/mpido_alltoall.c
index c16169c..f5b0e6d 100644
--- a/mpich2/src/mpid/dcmfd/src/coll/alltoall/mpido_alltoall.c
+++ b/mpich2/src/mpid/dcmfd/src/coll/alltoall/mpido_alltoall.c
@@ -80,9 +80,9 @@ MPIDO_Alltoall(void *sendbuf,
                            trcvlen, dt_null, rdt_true_lb);
 
    MPID_Ensure_Aint_fits_in_pointer(
-      MPI_VOID_PTR_CAST_TO_MPI_AINT sendbuf + sdt_true_lb);
+      MPIR_VOID_PTR_CAST_TO_MPI_AINT sendbuf + sdt_true_lb);
    MPID_Ensure_Aint_fits_in_pointer( 
-      MPI_VOID_PTR_CAST_TO_MPI_AINT recvbuf + rdt_true_lb);
+      MPIR_VOID_PTR_CAST_TO_MPI_AINT recvbuf + rdt_true_lb);
 
    if(sendcount == 0 || recvcount == 0)
       return MPI_SUCCESS;
diff --git a/mpich2/src/mpid/dcmfd/src/coll/alltoallv/mpido_alltoallv.c b/mpich2/src/mpid/dcmfd/src/coll/alltoallv/mpido_alltoallv.c
index 74a9030..b86f96a 100644
--- a/mpich2/src/mpid/dcmfd/src/coll/alltoallv/mpido_alltoallv.c
+++ b/mpich2/src/mpid/dcmfd/src/coll/alltoallv/mpido_alltoallv.c
@@ -79,9 +79,9 @@ MPIDO_Alltoallv(void *sendbuf,
    MPIDI_Datatype_get_info(1, recvtype, rcv_contig, trcvlen,
                            dt_null, rdt_true_lb);
    MPID_Ensure_Aint_fits_in_pointer(
-      MPI_VOID_PTR_CAST_TO_MPI_AINT sendbuf + sdt_true_lb);
+      MPIR_VOID_PTR_CAST_TO_MPI_AINT sendbuf + sdt_true_lb);
    MPID_Ensure_Aint_fits_in_pointer( 
-      MPI_VOID_PTR_CAST_TO_MPI_AINT recvbuf + rdt_true_lb);
+      MPIR_VOID_PTR_CAST_TO_MPI_AINT recvbuf + rdt_true_lb);
 
 
    if(!comm_ptr->dcmf.alltoalls ||
diff --git a/mpich2/src/mpid/dcmfd/src/coll/alltoallw/mpido_alltoallw.c b/mpich2/src/mpid/dcmfd/src/coll/alltoallw/mpido_alltoallw.c
index 4e96122..825ca8e 100644
--- a/mpich2/src/mpid/dcmfd/src/coll/alltoallw/mpido_alltoallw.c
+++ b/mpich2/src/mpid/dcmfd/src/coll/alltoallw/mpido_alltoallw.c
@@ -89,9 +89,9 @@ MPIDO_Alltoallw(void *sendbuf,
                            dt_null, rdt_true_lb);
 
       MPID_Ensure_Aint_fits_in_pointer(
-         MPI_VOID_PTR_CAST_TO_MPI_AINT sendbuf + sdt_true_lb);
+         MPIR_VOID_PTR_CAST_TO_MPI_AINT sendbuf + sdt_true_lb);
       MPID_Ensure_Aint_fits_in_pointer( 
-         MPI_VOID_PTR_CAST_TO_MPI_AINT recvbuf + rdt_true_lb);
+         MPIR_VOID_PTR_CAST_TO_MPI_AINT recvbuf + rdt_true_lb);
 
 
       if(!comm_ptr->dcmf.alltoalls ||
diff --git a/mpich2/src/mpid/dcmfd/src/coll/bcast/mpido_bcast.c b/mpich2/src/mpid/dcmfd/src/coll/bcast/mpido_bcast.c
index 8a928f8..b02d435 100644
--- a/mpich2/src/mpid/dcmfd/src/coll/bcast/mpido_bcast.c
+++ b/mpich2/src/mpid/dcmfd/src/coll/bcast/mpido_bcast.c
@@ -201,7 +201,7 @@ int MPIDO_Bcast(void * buffer,
                            dt_true_lb);
 
    MPID_Ensure_Aint_fits_in_pointer ( 
-      (MPI_VOID_PTR_CAST_TO_MPI_AINT buffer + dt_true_lb));
+      (MPIR_VOID_PTR_CAST_TO_MPI_AINT buffer + dt_true_lb));
    data_buffer = (char *)buffer+dt_true_lb;
 
   /* tree asserts if the data type size is actually 0. should we make
diff --git a/mpich2/src/mpid/dcmfd/src/coll/gather/mpido_gather.c b/mpich2/src/mpid/dcmfd/src/coll/gather/mpido_gather.c
index 350b805..b354b74 100644
--- a/mpich2/src/mpid/dcmfd/src/coll/gather/mpido_gather.c
+++ b/mpich2/src/mpid/dcmfd/src/coll/gather/mpido_gather.c
@@ -157,11 +157,11 @@ int MPIDO_Gather(void *sendbuf,
    {
       if(sendbuf != MPI_IN_PLACE)
       {
-         MPID_Ensure_Aint_fits_in_pointer(MPI_VOID_PTR_CAST_TO_MPI_AINT sendbuf + 
+         MPID_Ensure_Aint_fits_in_pointer(MPIR_VOID_PTR_CAST_TO_MPI_AINT sendbuf + 
                                        true_lb);
          sendbuf = (char *)sendbuf + true_lb;
       }
-      MPID_Ensure_Aint_fits_in_pointer(MPI_VOID_PTR_CAST_TO_MPI_AINT recvbuf + 
+      MPID_Ensure_Aint_fits_in_pointer(MPIR_VOID_PTR_CAST_TO_MPI_AINT recvbuf + 
                                        true_lb);
       recvbuf = (char *)recvbuf + true_lb;
 
diff --git a/mpich2/src/mpid/dcmfd/src/coll/reduce/mpido_reduce.c b/mpich2/src/mpid/dcmfd/src/coll/reduce/mpido_reduce.c
index 1d6ce2b..803abe3 100644
--- a/mpich2/src/mpid/dcmfd/src/coll/reduce/mpido_reduce.c
+++ b/mpich2/src/mpid/dcmfd/src/coll/reduce/mpido_reduce.c
@@ -266,13 +266,13 @@ int MPIDO_Reduce(void * sendbuf,
    unsigned usingrect=1 && rectavail;
    unsigned usingrectring=(rectringavail && count > 16384);
 
-   MPID_Ensure_Aint_fits_in_pointer( MPI_VOID_PTR_CAST_TO_MPI_AINT recvbuf + 
+   MPID_Ensure_Aint_fits_in_pointer( MPIR_VOID_PTR_CAST_TO_MPI_AINT recvbuf + 
                                     dt_true_lb);
    recvbuf = (char *)recvbuf + dt_true_lb;
 
    if(sendbuf != MPI_IN_PLACE)
    {
-      MPID_Ensure_Aint_fits_in_pointer (MPI_VOID_PTR_CAST_TO_MPI_AINT sendbuf +
+      MPID_Ensure_Aint_fits_in_pointer (MPIR_VOID_PTR_CAST_TO_MPI_AINT sendbuf +
                                         dt_true_lb);
       sendbuf = (char *)sendbuf + dt_true_lb;
      //      int err =
diff --git a/mpich2/src/mpid/dcmfd/src/coll/reduce_scatter/mpido_reduce_scatter.c b/mpich2/src/mpid/dcmfd/src/coll/reduce_scatter/mpido_reduce_scatter.c
index 014fb53..d2eba18 100644
--- a/mpich2/src/mpid/dcmfd/src/coll/reduce_scatter/mpido_reduce_scatter.c
+++ b/mpich2/src/mpid/dcmfd/src/coll/reduce_scatter/mpido_reduce_scatter.c
@@ -80,7 +80,7 @@ int MPIDO_Reduce_scatter(void *sendbuf,
 
    memset(displs, 0, size*sizeof(int));
 
-   MPID_Ensure_Aint_fits_in_pointer (MPI_VOID_PTR_CAST_TO_MPI_AINT sendbuf + 
+   MPID_Ensure_Aint_fits_in_pointer (MPIR_VOID_PTR_CAST_TO_MPI_AINT sendbuf + 
                                      dt_lb);
    sendbuf = (char *)sendbuf + dt_lb;
 
diff --git a/mpich2/src/mpid/dcmfd/src/coll/scatter/mpido_scatter.c b/mpich2/src/mpid/dcmfd/src/coll/scatter/mpido_scatter.c
index 025dd73..702ed04 100644
--- a/mpich2/src/mpid/dcmfd/src/coll/scatter/mpido_scatter.c
+++ b/mpich2/src/mpid/dcmfd/src/coll/scatter/mpido_scatter.c
@@ -114,12 +114,12 @@ int MPIDO_Scatter(void *sendbuf,
 
    if(bcastscatter)
    {
-      MPID_Ensure_Aint_fits_in_pointer (MPI_VOID_PTR_CAST_TO_MPI_AINT sendbuf +
+      MPID_Ensure_Aint_fits_in_pointer (MPIR_VOID_PTR_CAST_TO_MPI_AINT sendbuf +
                                         true_lb);
       sendbuf = (char *)sendbuf + true_lb;
       if(recvbuf != MPI_IN_PLACE)
       {
-         MPID_Ensure_Aint_fits_in_pointer (MPI_VOID_PTR_CAST_TO_MPI_AINT recvbuf +
+         MPID_Ensure_Aint_fits_in_pointer (MPIR_VOID_PTR_CAST_TO_MPI_AINT recvbuf +
                                         true_lb);
          recvbuf = (char *)recvbuf + true_lb;
       }
diff --git a/mpich2/src/mpid/dcmfd/src/coll/scatterv/mpido_scatterv.c b/mpich2/src/mpid/dcmfd/src/coll/scatterv/mpido_scatterv.c
index 8befe04..61d73f6 100644
--- a/mpich2/src/mpid/dcmfd/src/coll/scatterv/mpido_scatterv.c
+++ b/mpich2/src/mpid/dcmfd/src/coll/scatterv/mpido_scatterv.c
@@ -270,7 +270,7 @@ int MPIDO_Scatterv(void *sendbuf,
    {
       if(rank == root)
       {
-         MPID_Ensure_Aint_fits_in_pointer(MPI_VOID_PTR_CAST_TO_MPI_AINT sendbuf
+         MPID_Ensure_Aint_fits_in_pointer(MPIR_VOID_PTR_CAST_TO_MPI_AINT sendbuf
                                           + true_lb);
          sendbuf = (char *)sendbuf + true_lb;
       }
@@ -278,7 +278,7 @@ int MPIDO_Scatterv(void *sendbuf,
       {
          if(recvbuf != MPI_IN_PLACE)
          {
-            MPID_Ensure_Aint_fits_in_pointer(MPI_VOID_PTR_CAST_TO_MPI_AINT recvbuf
+            MPID_Ensure_Aint_fits_in_pointer(MPIR_VOID_PTR_CAST_TO_MPI_AINT recvbuf
                                           + true_lb);
             recvbuf = (char *)recvbuf + true_lb;
          }
diff --git a/mpich2/src/mpid/common/datatype/dataloop/segment_ops.c b/mpich2/src/mpid/common/datatype/dataloop/segment_ops.c
index c7e5473..0700f29 100644
--- a/mpich2/src/mpid/common/datatype/dataloop/segment_ops.c
+++ b/mpich2/src/mpid/common/datatype/dataloop/segment_ops.c
@@ -38,22 +38,22 @@ int PREPEND_PREFIX(Segment_contig_m2m)(DLOOP_Offset *blocks_p,
     if (paramp->direction == DLOOP_M2M_TO_USERBUF) {
 	/* Ensure that pointer increment fits in a pointer */
 	/* userbuf is a pointer (not a displacement) since it is being used on a memcpy */
-	MPID_Ensure_Aint_fits_in_pointer( (MPI_VOID_PTR_CAST_TO_MPI_AINT (paramp->userbuf)) + rel_off );
-	memcpy((char *) MPI_AINT_CAST_TO_VOID_PTR ((MPI_VOID_PTR_CAST_TO_MPI_AINT (paramp->userbuf)) + rel_off), 
+	MPID_Ensure_Aint_fits_in_pointer( (MPIR_VOID_PTR_CAST_TO_MPI_AINT (paramp->userbuf)) + rel_off );
+	memcpy((char *) MPIR_MPI_AINT_CAST_TO_VOID_PTR ((MPIR_VOID_PTR_CAST_TO_MPI_AINT (paramp->userbuf)) + rel_off), 
 	       paramp->streambuf, 
 	       size);
     }
     else {
 	/* Ensure that pointer increment fits in a pointer */
 	/* userbuf is a pointer (not a displacement) since it is being used on a memcpy */
-	MPID_Ensure_Aint_fits_in_pointer( (MPI_VOID_PTR_CAST_TO_MPI_AINT (paramp->userbuf)) + rel_off );
+	MPID_Ensure_Aint_fits_in_pointer( (MPIR_VOID_PTR_CAST_TO_MPI_AINT (paramp->userbuf)) + rel_off );
 	memcpy(paramp->streambuf, 
-	       (char *) ( MPI_AINT_CAST_TO_VOID_PTR ((MPI_VOID_PTR_CAST_TO_MPI_AINT (paramp->userbuf)) + rel_off) ), 
+	       (char *) ( MPIR_MPI_AINT_CAST_TO_VOID_PTR ((MPIR_VOID_PTR_CAST_TO_MPI_AINT (paramp->userbuf)) + rel_off) ), 
 	       size);
     }
     /* Ensure that pointer increment fits in a pointer */
     /* streambuf is a pointer (not a displacement) since it was used on a memcpy */
-    MPID_Ensure_Aint_fits_in_pointer( (MPI_VOID_PTR_CAST_TO_MPI_AINT (paramp->streambuf)) + size );
+    MPID_Ensure_Aint_fits_in_pointer( (MPIR_VOID_PTR_CAST_TO_MPI_AINT (paramp->streambuf)) + size );
     paramp->streambuf += size;
     return 0;
 }
@@ -81,8 +81,8 @@ int PREPEND_PREFIX(Segment_vector_m2m)(DLOOP_Offset *blocks_p,
 
     /* Ensure that pointer increment fits in a pointer */
     /* userbuf is a pointer (not a displacement) since it is being used for a memory copy */
-    MPID_Ensure_Aint_fits_in_pointer( (MPI_VOID_PTR_CAST_TO_MPI_AINT (paramp->userbuf)) + rel_off );
-    cbufp = (char*)( MPI_AINT_CAST_TO_VOID_PTR ( (MPI_VOID_PTR_CAST_TO_MPI_AINT (paramp->userbuf)) + rel_off ) );
+    MPID_Ensure_Aint_fits_in_pointer( (MPIR_VOID_PTR_CAST_TO_MPI_AINT (paramp->userbuf)) + rel_off );
+    cbufp = (char*)( MPIR_MPI_AINT_CAST_TO_VOID_PTR ( (MPIR_VOID_PTR_CAST_TO_MPI_AINT (paramp->userbuf)) + rel_off ) );
     DLOOP_Handle_get_size_macro(el_type, el_size);
 
     whole_count = (blksz > 0) ? (*blocks_p / (DLOOP_Offset)blksz) : 0;
@@ -116,18 +116,18 @@ int PREPEND_PREFIX(Segment_vector_m2m)(DLOOP_Offset *blocks_p,
 		memcpy(cbufp, paramp->streambuf, ((DLOOP_Offset)blksz) * el_size);
 		/* Ensure that pointer increment fits in a pointer */
 		/* streambuf is a pointer (not a displacement) since it is being used for a memory copy */
-		MPID_Ensure_Aint_fits_in_pointer( (MPI_VOID_PTR_CAST_TO_MPI_AINT (paramp->streambuf)) + 
+		MPID_Ensure_Aint_fits_in_pointer( (MPIR_VOID_PTR_CAST_TO_MPI_AINT (paramp->streambuf)) + 
 						  ((DLOOP_Offset)blksz) * el_size );
 		paramp->streambuf += ((DLOOP_Offset)blksz) * el_size;
 
-		MPID_Ensure_Aint_fits_in_pointer( (MPI_VOID_PTR_CAST_TO_MPI_AINT (cbufp)) + stride );
+		MPID_Ensure_Aint_fits_in_pointer( (MPIR_VOID_PTR_CAST_TO_MPI_AINT (cbufp)) + stride );
 		cbufp += stride;
 	    }
 	    if (blocks_left) {
 		memcpy(cbufp, paramp->streambuf, ((DLOOP_Offset)blocks_left) * el_size);
 		/* Ensure that pointer increment fits in a pointer */
 		/* streambuf is a pointer (not a displacement) since it is being used for a memory copy */
-		MPID_Ensure_Aint_fits_in_pointer( (MPI_VOID_PTR_CAST_TO_MPI_AINT (paramp->streambuf)) + 
+		MPID_Ensure_Aint_fits_in_pointer( (MPIR_VOID_PTR_CAST_TO_MPI_AINT (paramp->streambuf)) + 
 						  ((DLOOP_Offset)blocks_left) * el_size );
 		paramp->streambuf += ((DLOOP_Offset)blocks_left) * el_size;
 	    }
@@ -161,7 +161,7 @@ int PREPEND_PREFIX(Segment_vector_m2m)(DLOOP_Offset *blocks_p,
 		memcpy(paramp->streambuf, cbufp, (DLOOP_Offset)blksz * el_size);
 		/* Ensure that pointer increment fits in a pointer */
 		/* streambuf is a pointer (not a displacement) since it is being used for a memory copy */
-		MPID_Ensure_Aint_fits_in_pointer( (MPI_VOID_PTR_CAST_TO_MPI_AINT (paramp->streambuf)) + 
+		MPID_Ensure_Aint_fits_in_pointer( (MPIR_VOID_PTR_CAST_TO_MPI_AINT (paramp->streambuf)) + 
 						  (DLOOP_Offset)blksz * el_size );
 		paramp->streambuf += (DLOOP_Offset)blksz * el_size;
 		cbufp += stride;
@@ -170,7 +170,7 @@ int PREPEND_PREFIX(Segment_vector_m2m)(DLOOP_Offset *blocks_p,
 		memcpy(paramp->streambuf, cbufp, (DLOOP_Offset)blocks_left * el_size);
 		/* Ensure that pointer increment fits in a pointer */
 		/* streambuf is a pointer (not a displacement) since it is being used for a memory copy */
-		MPID_Ensure_Aint_fits_in_pointer( (MPI_VOID_PTR_CAST_TO_MPI_AINT (paramp->streambuf)) + 
+		MPID_Ensure_Aint_fits_in_pointer( (MPIR_VOID_PTR_CAST_TO_MPI_AINT (paramp->streambuf)) + 
 						  (DLOOP_Offset)blocks_left * el_size );
 		paramp->streambuf += (DLOOP_Offset)blocks_left * el_size;
 	    }
@@ -206,10 +206,10 @@ int PREPEND_PREFIX(Segment_blkidx_m2m)(DLOOP_Offset *blocks_p,
 
 	/* Ensure that pointer increment fits in a pointer */
 	/* userbuf is a pointer (not a displacement) since it is being used for a memory copy */
-	MPID_Ensure_Aint_fits_in_pointer( (MPI_VOID_PTR_CAST_TO_MPI_AINT (paramp->userbuf)) + 
+	MPID_Ensure_Aint_fits_in_pointer( (MPIR_VOID_PTR_CAST_TO_MPI_AINT (paramp->userbuf)) + 
 					  rel_off + offsetarray[curblock] );
-	cbufp = (char*) MPI_AINT_CAST_TO_VOID_PTR
-	          ((MPI_VOID_PTR_CAST_TO_MPI_AINT (paramp->userbuf)) + 
+	cbufp = (char*) MPIR_MPI_AINT_CAST_TO_VOID_PTR
+	          ((MPIR_VOID_PTR_CAST_TO_MPI_AINT (paramp->userbuf)) + 
 		   rel_off + offsetarray[curblock]);
 
 	if (blocklen > blocks_left) blocklen = blocks_left;
@@ -243,7 +243,7 @@ int PREPEND_PREFIX(Segment_blkidx_m2m)(DLOOP_Offset *blocks_p,
 
 	/* Ensure that pointer increment fits in a pointer */
 	/* streambuf is a pointer (not a displacement) since it is being used for a memory copy */
-	MPID_Ensure_Aint_fits_in_pointer( (MPI_VOID_PTR_CAST_TO_MPI_AINT (paramp->streambuf)) + 
+	MPID_Ensure_Aint_fits_in_pointer( (MPIR_VOID_PTR_CAST_TO_MPI_AINT (paramp->streambuf)) + 
 					  (DLOOP_Offset)blocklen * el_size );
 	paramp->streambuf += (DLOOP_Offset)blocklen * el_size;
 	blocks_left -= blocklen;
@@ -280,10 +280,10 @@ int PREPEND_PREFIX(Segment_index_m2m)(DLOOP_Offset *blocks_p,
 
 	/* Ensure that pointer increment fits in a pointer */
 	/* userbuf is a pointer (not a displacement) since it is being used for a memory copy */
-	MPID_Ensure_Aint_fits_in_pointer( (MPI_VOID_PTR_CAST_TO_MPI_AINT (paramp->userbuf)) + 
+	MPID_Ensure_Aint_fits_in_pointer( (MPIR_VOID_PTR_CAST_TO_MPI_AINT (paramp->userbuf)) + 
 					  rel_off + offsetarray[curblock]);
-	cbufp = (char*) MPI_AINT_CAST_TO_VOID_PTR
-	          ((MPI_VOID_PTR_CAST_TO_MPI_AINT (paramp->userbuf)) + 
+	cbufp = (char*) MPIR_MPI_AINT_CAST_TO_VOID_PTR
+	          ((MPIR_VOID_PTR_CAST_TO_MPI_AINT (paramp->userbuf)) + 
 		   rel_off + offsetarray[curblock]);
 
 	if (cur_block_sz > blocks_left) cur_block_sz = blocks_left;
@@ -317,7 +317,7 @@ int PREPEND_PREFIX(Segment_index_m2m)(DLOOP_Offset *blocks_p,
 
 	/* Ensure that pointer increment fits in a pointer */
 	/* streambuf is a pointer (not a displacement) since it is being used for a memory copy */
-	MPID_Ensure_Aint_fits_in_pointer( (MPI_VOID_PTR_CAST_TO_MPI_AINT (paramp->streambuf)) + 
+	MPID_Ensure_Aint_fits_in_pointer( (MPIR_VOID_PTR_CAST_TO_MPI_AINT (paramp->streambuf)) + 
 					  cur_block_sz * el_size );
 	paramp->streambuf += cur_block_sz * el_size;
 	blocks_left -= cur_block_sz;
@@ -636,7 +636,7 @@ static int DLOOP_Segment_contig_mpi_flatten(DLOOP_Offset *blocks_p,
 	 * disps + blklens fits in a pointer.  Just let it truncate, if the sizeof a pointer is less 
 	 * than the sizeof an MPI_Aint.
 	 */
-	last_end = (char*) MPI_AINT_CAST_TO_VOID_PTR
+	last_end = (char*) MPIR_MPI_AINT_CAST_TO_VOID_PTR
 	           (paramp->disps[last_idx] + ((DLOOP_Offset)paramp->blklens[last_idx]));
     }
 
@@ -661,10 +661,10 @@ static int DLOOP_Segment_contig_mpi_flatten(DLOOP_Offset *blocks_p,
     }
     else {
 	/* Since bufp can be a displacement and can be negative, we cannot use 
 	 * MPI_VOID_PTR_CAST_TO_MPI_AINT to cast the sum to a pointer.  Just let it
 	 * sign extend.
 	 */
-        paramp->disps[last_idx+1]   = MPI_PTR_DISP_CAST_TO_MPI_AINT bufp + rel_off;
+        paramp->disps[last_idx+1]   = MPIR_PTR_DISP_CAST_TO_MPI_AINT bufp + rel_off;
 	paramp->blklens[last_idx+1] = size;
 	paramp->index++;
     }
@@ -720,11 +720,11 @@ static int DLOOP_Segment_vector_mpi_flatten(DLOOP_Offset *blocks_p,
 	last_idx = paramp->index - 1;
 	if (last_idx >= 0) {
 	    /* Since disps can be negative, we cannot use MPID_Ensure_Aint_fits_in_pointer to verify that
 	     * disps + blklens fits in a pointer.  Nor can we use MPI_AINT_CAST_TO_VOID_PTR to cast the 
 	     * sum to a pointer.  Just let it truncate, if the sizeof a pointer is less than the sizeof
 	     * an MPI_Aint.
 	     */
-	    last_end = (char *) MPI_AINT_CAST_TO_VOID_PTR
+	    last_end = (char *) MPIR_MPI_AINT_CAST_TO_VOID_PTR
 		       ( paramp->disps[last_idx] +
 			 (MPI_Aint)(paramp->blklens[last_idx]) );
 	}
@@ -754,10 +754,10 @@ static int DLOOP_Segment_vector_mpi_flatten(DLOOP_Offset *blocks_p,
 	}
 	else {
 	    /* Since bufp can be a displacement and can be negative, we cannot use 
 	     * MPI_VOID_PTR_CAST_TO_MPI_AINT to cast the sum to a pointer.  Just let it
 	     * sign extend.
 	     */
-            paramp->disps[last_idx+1]   = MPI_PTR_DISP_CAST_TO_MPI_AINT bufp + rel_off;
+            paramp->disps[last_idx+1]   = MPIR_PTR_DISP_CAST_TO_MPI_AINT bufp + rel_off;
 	    paramp->blklens[last_idx+1] = size;
 	    paramp->index++;
 	}
@@ -812,11 +812,11 @@ static int DLOOP_Segment_blkidx_mpi_flatten(DLOOP_Offset *blocks_p,
 	last_idx = paramp->index - 1;
 	if (last_idx >= 0) {
 	    /* Since disps can be negative, we cannot use MPID_Ensure_Aint_fits_in_pointer to verify that
 	     * disps + blklens fits in a pointer.  Nor can we use MPI_AINT_CAST_TO_VOID_PTR to cast the 
 	     * sum to a pointer.  Just let it truncate, if the sizeof a pointer is less than the sizeof
 	     * an MPI_Aint.
 	     */
-	    last_end = (char*) MPI_AINT_CAST_TO_VOID_PTR
+	    last_end = (char*) MPIR_MPI_AINT_CAST_TO_VOID_PTR
 		       (paramp->disps[last_idx] + ((DLOOP_Offset)paramp->blklens[last_idx]));
 	}
 
@@ -845,10 +845,10 @@ static int DLOOP_Segment_blkidx_mpi_flatten(DLOOP_Offset *blocks_p,
 	}
 	else {
 	    /* Since bufp can be a displacement and can be negative, we cannot use 
 	     * MPI_VOID_PTR_CAST_TO_MPI_AINT to cast the sum to a pointer.  Just let it
 	     * sign extend.
 	     */
-            paramp->disps[last_idx+1]   = MPI_PTR_DISP_CAST_TO_MPI_AINT bufp + rel_off + offsetarray[last_idx+1];
+            paramp->disps[last_idx+1]   = MPIR_PTR_DISP_CAST_TO_MPI_AINT bufp + rel_off + offsetarray[last_idx+1];
 	    paramp->blklens[last_idx+1] = size;
 	    paramp->index++;
 	}
@@ -903,11 +903,11 @@ static int DLOOP_Segment_index_mpi_flatten(DLOOP_Offset *blocks_p,
 	last_idx = paramp->index - 1;
 	if (last_idx >= 0) {
 	    /* Since disps can be negative, we cannot use MPID_Ensure_Aint_fits_in_pointer to verify that
 	     * disps + blklens fits in a pointer.  Nor can we use MPI_AINT_CAST_TO_VOID_PTR to cast the 
 	     * sum to a pointer.  Just let it truncate, if the sizeof a pointer is less than the sizeof
 	     * an MPI_Aint.
 	     */
-	    last_end = (char *) MPI_AINT_CAST_TO_VOID_PTR
+	    last_end = (char *) MPIR_MPI_AINT_CAST_TO_VOID_PTR
 		       ( paramp->disps[last_idx] +
 			 (MPI_Aint)(paramp->blklens[last_idx]) );
 	}
@@ -937,10 +937,10 @@ static int DLOOP_Segment_index_mpi_flatten(DLOOP_Offset *blocks_p,
 	}
 	else {
 	    /* Since bufp can be a displacement and can be negative, we cannot use 
 	     * MPI_VOID_PTR_CAST_TO_MPI_AINT to cast the sum to a pointer.  Just let it
 	     * sign extend.
 	     */
-            paramp->disps[last_idx+1]   = MPI_PTR_DISP_CAST_TO_MPI_AINT bufp + rel_off + offsetarray[last_idx+1];
+            paramp->disps[last_idx+1]   = MPIR_PTR_DISP_CAST_TO_MPI_AINT bufp + rel_off + offsetarray[last_idx+1];
 	    paramp->blklens[last_idx+1] = size;
 	    paramp->index++;
 	}
@@ -661,10 +661,10 @@ static int DLOOP_Segment_contig_mpi_flatten(DLOOP_Offset *blocks_p,
     else {
 	/* Since bufp can be a displacement and can be negative, we cannot use 
-	 * MPI_VOID_PTR_CAST_TO_MPI_AINT to cast the sum to a pointer.  Just let it
+	 * MPIR_VOID_PTR_CAST_TO_MPI_AINT to cast the sum to a pointer.  Just let it
 	 * sign extend.
 	 */
@@ -720,11 +720,11 @@ static int DLOOP_Segment_vector_mpi_flatten(DLOOP_Offset *blocks_p,
 	if (last_idx >= 0) {
 	    /* Since disps can be negative, we cannot use MPID_Ensure_Aint_fits_in_pointer to verify that
-	     * disps + blklens fits in a pointer.  Nor can we use MPI_AINT_CAST_TO_VOID_PTR to cast the 
+	     * disps + blklens fits in a pointer.  Nor can we use MPIR_MPI_AINT_CAST_TO_VOID_PTR to cast the 
 	     * sum to a pointer.  Just let it truncate, if the sizeof a pointer is less than the sizeof
 	     * an MPI_Aint.
@@ -754,10 +754,10 @@ static int DLOOP_Segment_vector_mpi_flatten(DLOOP_Offset *blocks_p,
 	else {
 	    /* Since bufp can be a displacement and can be negative, we cannot use 
-	     * MPI_VOID_PTR_CAST_TO_MPI_AINT to cast the sum to a pointer.  Just let it
+	     * MPIR_VOID_PTR_CAST_TO_MPI_AINT to cast the sum to a pointer.  Just let it
 	     * sign extend.
 	     */
@@ -812,11 +812,11 @@ static int DLOOP_Segment_blkidx_mpi_flatten(DLOOP_Offset *blocks_p,
 	if (last_idx >= 0) {
 	    /* Since disps can be negative, we cannot use MPID_Ensure_Aint_fits_in_pointer to verify that
-	     * disps + blklens fits in a pointer.  Nor can we use MPI_AINT_CAST_TO_VOID_PTR to cast the 
+	     * disps + blklens fits in a pointer.  Nor can we use MPIR_MPI_AINT_CAST_TO_VOID_PTR to cast the 
 	     * sum to a pointer.  Just let it truncate, if the sizeof a pointer is less than the sizeof
 	     * an MPI_Aint.
@@ -845,10 +845,10 @@ static int DLOOP_Segment_blkidx_mpi_flatten(DLOOP_Offset *blocks_p,
 	else {
 	    /* Since bufp can be a displacement and can be negative, we cannot use 
-	     * MPI_VOID_PTR_CAST_TO_MPI_AINT to cast the sum to a pointer.  Just let it
+	     * MPIR_VOID_PTR_CAST_TO_MPI_AINT to cast the sum to a pointer.  Just let it
 	     * sign extend.
 	     */
@@ -903,11 +903,11 @@ static int DLOOP_Segment_index_mpi_flatten(DLOOP_Offset *blocks_p,
 	if (last_idx >= 0) {
 	    /* Since disps can be negative, we cannot use MPID_Ensure_Aint_fits_in_pointer to verify that
-	     * disps + blklens fits in a pointer.  Nor can we use MPI_AINT_CAST_TO_VOID_PTR to cast the 
+	     * disps + blklens fits in a pointer.  Nor can we use MPIR_MPI_AINT_CAST_TO_VOID_PTR to cast the 
 	     * sum to a pointer.  Just let it truncate, if the sizeof a pointer is less than the sizeof
 	     * an MPI_Aint.
@@ -937,10 +937,10 @@ static int DLOOP_Segment_index_mpi_flatten(DLOOP_Offset *blocks_p,
 	else {
 	    /* Since bufp can be a displacement and can be negative, we cannot use 
-	     * MPI_VOID_PTR_CAST_TO_MPI_AINT to cast the sum to a pointer.  Just let it
+	     * MPIR_VOID_PTR_CAST_TO_MPI_AINT to cast the sum to a pointer.  Just let it
 	     * sign extend.
 	     */
-- 
1.5.3.7




More information about the mpich2-dev mailing list